Class: Google::Apis::ServiceusageV1::BatchEnableServicesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Response message for the BatchEnableServices method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchEnableServicesResponse

Returns a new instance of BatchEnableServicesResponse.



745
746
747
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failuresArray<Google::Apis::ServiceusageV1::EnableFailure>

If allow_partial_success is true, and one or more services could not be enabled, this field contains the details about each failure. Corresponds to the JSON property failures



738
739
740
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 738

def failures
  @failures
end

#servicesArray<Google::Apis::ServiceusageV1::GoogleApiServiceusageV1Service>

The new state of the services after enabling. Corresponds to the JSON property services



743
744
745
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 743

def services
  @services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



750
751
752
753
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 750

def update!(**args)
  @failures = args[:failures] if args.key?(:failures)
  @services = args[:services] if args.key?(:services)
end