Class: Google::Apis::ServiceusageV1::ConsumerPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsumerPolicy

Returns a new instance of ConsumerPolicy.



1173
1174
1175
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the policy was created. For singleton policies, this is the first touch of the policy. Corresponds to the JSON property createTime

Returns:

  • (String)


1147
1148
1149
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1147

def create_time
  @create_time
end

#enable_rulesArray<Google::Apis::ServiceusageV1::EnableRule>

Enable rules define usable services and groups. There can currently be at most one EnableRule. This restriction will be lifted in later releases. Corresponds to the JSON property enableRules



1153
1154
1155
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1153

def enable_rules
  @enable_rules
end

#etagString

An opaque tag indicating the current version of the policy, used for concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


1159
1160
1161
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1159

def etag
  @etag
end

#nameString

Output only. The resource name of the policy. Only the default policy is supported: projects/12345/consumerPolicies/default, folders/12345/ consumerPolicies/default, organizations/12345/consumerPolicies/default. Corresponds to the JSON property name

Returns:

  • (String)


1166
1167
1168
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1166

def name
  @name
end

#update_timeString

Output only. The time the policy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1171
1172
1173
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1171

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1178
1179
1180
1181
1182
1183
1184
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1178

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @enable_rules = args[:enable_rules] if args.key?(:enable_rules)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end