Class: Google::Apis::ServiceusageV1::ContentSecurity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

ContentSecurity defines the content security related fields of a MCP policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentSecurity

Returns a new instance of ContentSecurity.



1162
1163
1164
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1162

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_security_providersArray<Google::Apis::ServiceusageV1::ContentSecurityProvider>

List of content security providers that are enabled for content scanning. Corresponds to the JSON property contentSecurityProviders



1160
1161
1162
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1160

def content_security_providers
  @content_security_providers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1167
1168
1169
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1167

def update!(**args)
  @content_security_providers = args[:content_security_providers] if args.key?(:content_security_providers)
end