Class: Google::Apis::ServiceusageV1::ContentSecurityPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Content Security Policy contains the content security related policy of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentSecurityPolicy

Returns a new instance of ContentSecurityPolicy.



1227
1228
1229
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mcp_content_securityGoogle::Apis::ServiceusageV1::ContentSecurity

ContentSecurity defines the content security related fields of a MCP policy. Corresponds to the JSON property mcpContentSecurity



1216
1217
1218
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1216

def mcp_content_security
  @mcp_content_security
end

#nameString

Output only. The resource name of the policy. Only the default policy is supported. We allow the following formats: projects/PROJECT_NUMBER/ contentSecurityPolicies/default, projects/PROJECT_ID/ contentSecurityPolicies/default, We only support project level content security policy for now. Corresponds to the JSON property name

Returns:

  • (String)


1225
1226
1227
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1225

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1232
1233
1234
1235
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1232

def update!(**args)
  @mcp_content_security = args[:mcp_content_security] if args.key?(:mcp_content_security)
  @name = args[:name] if args.key?(:name)
end