Class: Google::Apis::ServiceusageV1::ContentSecurityProvider
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::ContentSecurityProvider
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
ContentSecurityProvider contains the name of content security provider.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of security service for content scanning, such as Google Cloud Model Armor or supported third-party ISV solutions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentSecurityProvider
constructor
A new instance of ContentSecurityProvider.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentSecurityProvider
Returns a new instance of ContentSecurityProvider.
1215 1216 1217 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of security service for content scanning, such as Google Cloud Model
Armor or supported third-party ISV solutions. If it is Google 1P service, the
name should be prefixed with services/. If it is a 3P service, the format
needs to be documented. The currently supported values are: - services/
modelarmor.googleapis.com for Google Cloud Model Armor.
Corresponds to the JSON property name
1213 1214 1215 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1213 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1220 1221 1222 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1220 def update!(**args) @name = args[:name] if args.key?(:name) end |