Class: Google::Apis::ServiceusageV1::DisableServiceResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Response message for the DisableService method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DisableServiceResponse

Returns a new instance of DisableServiceResponse.



1541
1542
1543
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceGoogle::Apis::ServiceusageV1::GoogleApiServiceusageV1Service

A service that is available for use by the consumer. Corresponds to the JSON property service



1539
1540
1541
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1539

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1546
1547
1548
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1546

def update!(**args)
  @service = args[:service] if args.key?(:service)
end