Class: Google::Apis::ServiceusageV1::EnableRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

The consumer policy rule that defines enabled services and groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnableRule

Returns a new instance of EnableRule.



1816
1817
1818
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_typeString

Client and resource project enable type. Corresponds to the JSON property enableType

Returns:

  • (String)


1801
1802
1803
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1801

def enable_type
  @enable_type
end

#servicesArray<String>

The names of the services that are enabled. Example: services/storage. googleapis.com. Corresponds to the JSON property services

Returns:

  • (Array<String>)


1807
1808
1809
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1807

def services
  @services
end

#valuesArray<String>

The names of the services or service groups that are enabled. Example: services/storage.googleapis.com, groups/googleServices, groups/allServices . Corresponds to the JSON property values

Returns:

  • (Array<String>)


1814
1815
1816
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1814

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1821
1822
1823
1824
1825
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1821

def update!(**args)
  @enable_type = args[:enable_type] if args.key?(:enable_type)
  @services = args[:services] if args.key?(:services)
  @values = args[:values] if args.key?(:values)
end