Class: Google::Apis::ServiceusageV1::EnumValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnumValue

Returns a new instance of EnumValue.



1997
1998
1999
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Enum value name. Corresponds to the JSON property name

Returns:

  • (String)


1985
1986
1987
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1985

def name
  @name
end

#numberFixnum

Enum value number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1990
1991
1992
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1990

def number
  @number
end

#optionsArray<Google::Apis::ServiceusageV1::Option>

Protocol buffer options. Corresponds to the JSON property options



1995
1996
1997
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1995

def options
  @options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2002
2003
2004
2005
2006
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2002

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @options = args[:options] if args.key?(:options)
end