Class: Google::Apis::ServiceusageV1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



2113
2114
2115
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


2063
2064
2065
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2063

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


2068
2069
2070
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2068

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


2073
2074
2075
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2073

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


2078
2079
2080
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2078

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


2083
2084
2085
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2083

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


2088
2089
2090
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2088

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


2094
2095
2096
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2094

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::ServiceusageV1::Option>

The protocol buffer options. Corresponds to the JSON property options



2099
2100
2101
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2099

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


2104
2105
2106
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2104

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


2111
2112
2113
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2111

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2118

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end