Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaAnalyzeConsumerPolicyResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

The response of analyzing a consumer policy update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2alphaAnalyzeConsumerPolicyResponse

Returns a new instance of GoogleApiServiceusageV2alphaAnalyzeConsumerPolicyResponse.



2934
2935
2936
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysisArray<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaAnalysis>

The list of analyses returned from performing the intended policy update analysis. The analysis is grouped by service name and different analysis types. The empty analysis list means that the consumer policy can be updated without any warnings or blockers. Corresponds to the JSON property analysis



2932
2933
2934
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2932

def analysis
  @analysis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2939
2940
2941
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2939

def update!(**args)
  @analysis = args[:analysis] if args.key?(:analysis)
end