Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaConsumerPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2alphaConsumerPolicy

Returns a new instance of GoogleApiServiceusageV2alphaConsumerPolicy.



2988
2989
2990
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a policy that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. AIP- 128 Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2955
2956
2957
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2955

def annotations
  @annotations
end

#create_timeString

Output only. The time the policy was created. For singleton policies, this is the first touch of the policy. Corresponds to the JSON property createTime

Returns:

  • (String)


2961
2962
2963
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2961

def create_time
  @create_time
end

#enable_rulesArray<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaEnableRule>

Enable rules define usable services, groups, and categories. There can currently be at most one EnableRule. This restriction will be lifted in later releases. Corresponds to the JSON property enableRules



2968
2969
2970
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2968

def enable_rules
  @enable_rules
end

#etagString

Output only. An opaque tag indicating the current version of the policy, used for concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


2974
2975
2976
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2974

def etag
  @etag
end

#nameString

Output only. The resource name of the policy. Only the default policy is supported: projects/12345/consumerPolicies/default, folders/12345/ consumerPolicies/default, organizations/12345/consumerPolicies/default. Corresponds to the JSON property name

Returns:

  • (String)


2981
2982
2983
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2981

def name
  @name
end

#update_timeString

Output only. The time the policy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2986
2987
2988
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2986

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2993
2994
2995
2996
2997
2998
2999
3000
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2993

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @enable_rules = args[:enable_rules] if args.key?(:enable_rules)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end