Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaImpact
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaImpact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
A message to group impacts of updating a policy.
Instance Attribute Summary collapse
-
#detail ⇒ String
Output only.
-
#impact_type ⇒ String
Output only.
-
#parent ⇒ String
The parent resource that the analysis is based on and the service name that the analysis is for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2alphaImpact
constructor
A new instance of GoogleApiServiceusageV2alphaImpact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2alphaImpact
Returns a new instance of GoogleApiServiceusageV2alphaImpact.
3049 3050 3051 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detail ⇒ String
Output only. User friendly impact detail in a free form message.
Corresponds to the JSON property detail
3030 3031 3032 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3030 def detail @detail end |
#impact_type ⇒ String
Output only. The type of impact.
Corresponds to the JSON property impactType
3035 3036 3037 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3035 def impact_type @impact_type end |
#parent ⇒ String
The parent resource that the analysis is based on and the service name that
the analysis is for. Example: projects/100/services/compute.googleapis.com,
folders/101/services/compute.googleapis.comandorganizations/102/services/
compute.googleapis.com. Usually, the parent resource here is same as the
parent resource of the analyzed policy. However, for some analysis types, the
parent can be different. For example, for resource existence analysis, if the
parent resource of the analyzed policy is a folder or an organization, the
parent resource here can still be the project that contains the resources.
Corresponds to the JSON propertyparent`
3047 3048 3049 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3047 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3054 3055 3056 3057 3058 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3054 def update!(**args) @detail = args[:detail] if args.key?(:detail) @impact_type = args[:impact_type] if args.key?(:impact_type) @parent = args[:parent] if args.key?(:parent) end |