Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

A message to group the analysis information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaAnalysis

Returns a new instance of GoogleApiServiceusageV2betaAnalysis.



2972
2973
2974
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysis_resultGoogle::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysisResult

An analysis result including blockers and warnings. Corresponds to the JSON property analysisResult



2953
2954
2955
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2953

def analysis_result
  @analysis_result
end

#analysis_typeString

Output only. The type of analysis. Corresponds to the JSON property analysisType

Returns:

  • (String)


2958
2959
2960
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2958

def analysis_type
  @analysis_type
end

#display_nameString

Output only. The user friendly display name of the analysis type. E.g. service dependency analysis, service resource usage analysis, etc. Corresponds to the JSON property displayName

Returns:

  • (String)


2964
2965
2966
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2964

def display_name
  @display_name
end

#serviceString

The names of the service that has analysis result of warnings or blockers. Example: services/storage.googleapis.com. Corresponds to the JSON property service

Returns:

  • (String)


2970
2971
2972
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2970

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2977
2978
2979
2980
2981
2982
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2977

def update!(**args)
  @analysis_result = args[:analysis_result] if args.key?(:analysis_result)
  @analysis_type = args[:analysis_type] if args.key?(:analysis_type)
  @display_name = args[:display_name] if args.key?(:display_name)
  @service = args[:service] if args.key?(:service)
end