Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysisResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

An analysis result including blockers and warnings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaAnalysisResult

Returns a new instance of GoogleApiServiceusageV2betaAnalysisResult.



3000
3001
3002
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockersArray<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaImpact>

Blocking information that would prevent the policy changes at runtime. Corresponds to the JSON property blockers



2992
2993
2994
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2992

def blockers
  @blockers
end

#warningsArray<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaImpact>

Warning information indicating that the policy changes might be unsafe, but will not block the changes at runtime. Corresponds to the JSON property warnings



2998
2999
3000
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2998

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3005
3006
3007
3008
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3005

def update!(**args)
  @blockers = args[:blockers] if args.key?(:blockers)
  @warnings = args[:warnings] if args.key?(:warnings)
end