Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalyzeConsumerPolicyResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

The response of analyzing a consumer policy update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaAnalyzeConsumerPolicyResponse

Returns a new instance of GoogleApiServiceusageV2betaAnalyzeConsumerPolicyResponse.



3164
3165
3166
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3164

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analysisArray<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysis>

The list of analyses returned from performing the intended policy update analysis. The analysis is grouped by service name and different analysis types. The empty analysis list means that the consumer policy can be updated without any warnings or blockers. Corresponds to the JSON property analysis



3162
3163
3164
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3162

def analysis
  @analysis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3169
3170
3171
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3169

def update!(**args)
  @analysis = args[:analysis] if args.key?(:analysis)
end