Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaMcpService

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

McpService contains the service names that are enabled for MCP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaMcpService

Returns a new instance of GoogleApiServiceusageV2betaMcpService.



3198
3199
3200
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceString

The names of the services that are enabled for MCP. Example: services/library- example.googleapis.com Corresponds to the JSON property service

Returns:

  • (String)


3196
3197
3198
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3196

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3203
3204
3205
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3203

def update!(**args)
  @service = args[:service] if args.key?(:service)
end