Class: Google::Apis::ServiceusageV1::Impact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

A message to group impacts of updating a policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Impact

Returns a new instance of Impact.



3655
3656
3657
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Output only. User friendly impact detail in a free form message. Corresponds to the JSON property detail

Returns:

  • (String)


3640
3641
3642
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3640

def detail
  @detail
end

#impact_typeString

Output only. The type of impact. Corresponds to the JSON property impactType

Returns:

  • (String)


3645
3646
3647
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3645

def impact_type
  @impact_type
end

#missing_dependencyString

Output only. This field will be populated only for the DEPENDENCY_MISSING_DEPENDENCIES impact type. Example: services/compute. googleapis.com. Impact.detail will be in format : missing service dependency: missing_dependency. Corresponds to the JSON property missingDependency

Returns:

  • (String)


3653
3654
3655
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3653

def missing_dependency
  @missing_dependency
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3660
3661
3662
3663
3664
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3660

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @impact_type = args[:impact_type] if args.key?(:impact_type)
  @missing_dependency = args[:missing_dependency] if args.key?(:missing_dependency)
end