Class: Google::Apis::ServiceusageV1::McpPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

MCP Consumer Policy is a set of rules that define MCP related policy for a cloud resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ McpPolicy

Returns a new instance of McpPolicy.



4000
4001
4002
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the policy was created. For singleton policies (such as the default policy), this is the first touch of the policy. Corresponds to the JSON property createTime

Returns:

  • (String)


3974
3975
3976
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3974

def create_time
  @create_time
end

#etagString

An opaque tag indicating the current version of the policy, used for concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


3980
3981
3982
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3980

def etag
  @etag
end

#mcp_enable_rulesArray<Google::Apis::ServiceusageV1::McpEnableRule>

McpEnableRules contains MCP enablement related rules. Corresponds to the JSON property mcpEnableRules



3985
3986
3987
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3985

def mcp_enable_rules
  @mcp_enable_rules
end

#nameString

Output only. The resource name of the policy. Only the default policy is supported. We allow the following formats: projects/PROJECT_NUMBER/ mcpPolicies/default, projects/PROJECT_ID/mcpPolicies/default, folders/ FOLDER_ID/mcpPolicies/default, organizations/ORG_ID/mcpPolicies/default. Corresponds to the JSON property name

Returns:

  • (String)


3993
3994
3995
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3993

def name
  @name
end

#update_timeString

Output only. The time the policy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3998
3999
4000
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3998

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4005
4006
4007
4008
4009
4010
4011
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4005

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @mcp_enable_rules = args[:mcp_enable_rules] if args.key?(:mcp_enable_rules)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end