Class: Google::Apis::ServiceusageV1::McpService

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

McpService contains the service names that are enabled for MCP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ McpService

Returns a new instance of McpService.



4024
4025
4026
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceString

The names of the services that are enabled for MCP. Example: services/library- example.googleapis.com Corresponds to the JSON property service

Returns:

  • (String)


4022
4023
4024
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4022

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4029
4030
4031
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4029

def update!(**args)
  @service = args[:service] if args.key?(:service)
end