Class: Google::Apis::ServiceusageV1::MethodPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Defines policies applying to an RPC method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodPolicy

Returns a new instance of MethodPolicy.



4121
4122
4123
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_policiesArray<Google::Apis::ServiceusageV1::FieldPolicy>

Policies that are applicable to the request message. Corresponds to the JSON property requestPolicies



4111
4112
4113
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4111

def request_policies
  @request_policies
end

#selectorString

Selects a method to which these policies should be enforced, for example, " google.pubsub.v1.Subscriber.CreateSubscription". Refer to selector for syntax details. NOTE: This field must not be set in the proto annotation. It will be automatically filled by the service config compiler . Corresponds to the JSON property selector

Returns:

  • (String)


4119
4120
4121
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4119

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4126
4127
4128
4129
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4126

def update!(**args)
  @request_policies = args[:request_policies] if args.key?(:request_policies)
  @selector = args[:selector] if args.key?(:selector)
end