Class: Google::Apis::ServiceusageV1::MetricDescriptor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Defines a metric type and its schema. Once a metric descriptor is created, deleting or altering it stops data collection and makes the metric type's existing data unusable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricDescriptor

Returns a new instance of MetricDescriptor.



4245
4246
4247
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A detailed description of the metric, which can be used in documentation. Corresponds to the JSON property description

Returns:

  • (String)


4131
4132
4133
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4131

def description
  @description
end

#display_nameString

A concise name for the metric, which can be displayed in user interfaces. Use sentence case without an ending period, for example "Request count". This field is optional but it is recommended to be set for any metrics associated with user-visible concepts, such as Quota. Corresponds to the JSON property displayName

Returns:

  • (String)


4139
4140
4141
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4139

def display_name
  @display_name
end

#labelsArray<Google::Apis::ServiceusageV1::LabelDescriptor>

The set of labels that can be used to describe a specific instance of this metric type. For example, the appengine.googleapis.com/http/server/ response_latencies metric type has a label for the HTTP response code, response_code, so you can look at latencies for successful responses or just for responses that failed. Corresponds to the JSON property labels



4148
4149
4150
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4148

def labels
  @labels
end

#launch_stageString

Optional. The launch stage of the metric definition. Corresponds to the JSON property launchStage

Returns:

  • (String)


4153
4154
4155
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4153

def launch_stage
  @launch_stage
end

#metadataGoogle::Apis::ServiceusageV1::MetricDescriptorMetadata

Additional annotations that can be used to guide the usage of a metric. Corresponds to the JSON property metadata



4158
4159
4160
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4158

def 
  @metadata
end

#metric_kindString

Whether the metric records instantaneous values, changes to a value, etc. Some combinations of metric_kind and value_type might not be supported. Corresponds to the JSON property metricKind

Returns:

  • (String)


4164
4165
4166
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4164

def metric_kind
  @metric_kind
end

#monitored_resource_typesArray<String>

Read-only. If present, then a time series, which is identified partially by a metric type and a MonitoredResourceDescriptor, that is associated with this metric type can only be associated with one of the monitored resource types listed here. Corresponds to the JSON property monitoredResourceTypes

Returns:

  • (Array<String>)


4172
4173
4174
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4172

def monitored_resource_types
  @monitored_resource_types
end

#nameString

The resource name of the metric descriptor. Corresponds to the JSON property name

Returns:

  • (String)


4177
4178
4179
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4177

def name
  @name
end

#typeString

The metric type, including its DNS name prefix. The type is not URL-encoded. All user-defined metric types have the DNS name custom.googleapis.com or external.googleapis.com. Metric types should use a natural hierarchical grouping. For example: "custom.googleapis.com/invoice/paid/amount" "external. googleapis.com/prometheus/up" "appengine.googleapis.com/http/server/ response_latencies" Corresponds to the JSON property type

Returns:

  • (String)


4187
4188
4189
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4187

def type
  @type
end

#unitString

The units in which the metric value is reported. It is only applicable if the value_type is INT64, DOUBLE, or DISTRIBUTION. The unit defines the representation of the stored metric values. Different systems might scale the values to be more easily displayed (so a value of 0.02kBy might be displayed as 20By, and a value of 3523kBy might be displayed as 3.5MBy) . However, if the unit is kBy, then the value of the metric is always in thousands of bytes, no matter how it might be displayed. If you want a custom metric to record the exact number of CPU-seconds used by a job, you can create an INT64 CUMULATIVE metric whose unit is sCPU(or equivalently `1s`CPU` ` or just `s`). If the job uses 12,005 CPU-seconds, then the value is written as `12005`. Alternatively, if you want a custom metric to record data in a more granular way, you can create a `DOUBLE CUMULATIVE` metric whose `unit` is `ks`CPU, and then write the value 12.005 (which is 12005/1000), or use KisCPUand write `11.723` (which is `12005/1024`). The supported units are a subset of [The Unified Code for Units of Measure](https://unitsofmeasure.org/ ucum.html) standard: **Basic units (UNIT)** * `bit` bit * `By` byte * `s` second * `min` minute * `h` hour * `d` day * `1` dimensionless **Prefixes ( PREFIX)** * `k` kilo (10^3) * `M` mega (10^6) * `G` giga (10^9) * `T` tera (10^ 12) * `P` peta (10^15) * `E` exa (10^18) * `Z` zetta (10^21) * `Y` yotta (10^ 24) * `m` milli (10^-3) * `u` micro (10^-6) * `n` nano (10^-9) * `p` pico (10^- 12) * `f` femto (10^-15) * `a` atto (10^-18) * `z` zepto (10^-21) * `y` yocto ( 10^-24) * `Ki` kibi (2^10) * `Mi` mebi (2^20) * `Gi` gibi (2^30) * `Ti` tebi ( 2^40) * `Pi` pebi (2^50) **Grammar** The grammar also includes these connectors: * `/` division or ratio (as an infix operator). For examples, `kBy/ `email or MiBy/10ms (although you should almost never have /s in a metric unit; rates should always be computed at query time from the underlying cumulative or delta value). * . multiplication or composition (as an infix operator). For examples, GBy.d or kwatt.h. The grammar for a unit is as follows: Expression = Component "." Component "/" Component ; Component = ( [ PREFIX ] UNIT | "%" ) [ Annotation ] | Annotation | "1" ; Annotation = "" NAME "" ; Notes: * Annotation is just a comment if it follows a UNIT. If the annotation is used alone, then the unit is equivalent to 1. For examples, request`/s == 1/s`, `By`transmitted`/s == By/s`. * ` NAME` is a sequence of non-blank printable ASCII characters not containing or. * `1` represents a unitary [dimensionless unit](https://en.wikipedia. org/wiki/Dimensionless_quantity) of 1, such as in `1/s`. It is typically used when none of the basic units are appropriate. For example, "new users per day" can be represented as `1/d` ornew-users/d (and a metric value 5 would mean "5 new users). Alternatively, "thousands of page views per day" would be represented as 1000/d or k1/d or kpage_views/d (and a metric value of 5.3 would mean "5300 page views per day"). * % represents dimensionless value of 1/100, and annotates values giving a percentage (so the metric values are typically in the range of 0..100, and a metric value 3 means "3 percent") . * 10^2.% indicates a metric contains a ratio, typically in the range 0..1, that will be multiplied by 100 and displayed as a percentage (so a metric value 0.03 means "3 percent"). Corresponds to the JSON property unit

Returns:

  • (String)


4237
4238
4239
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4237

def unit
  @unit
end

#value_typeString

Whether the measurement is an integer, a floating-point number, etc. Some combinations of metric_kind and value_type might not be supported. Corresponds to the JSON property valueType

Returns:

  • (String)


4243
4244
4245
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4243

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4250

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metric_kind = args[:metric_kind] if args.key?(:metric_kind)
  @monitored_resource_types = args[:monitored_resource_types] if args.key?(:monitored_resource_types)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @unit = args[:unit] if args.key?(:unit)
  @value_type = args[:value_type] if args.key?(:value_type)
end