Class: Google::Apis::ServiceusageV1::MonitoringDestination
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::MonitoringDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
Configuration of a specific monitoring destination (the producer project or the consumer project).
Instance Attribute Summary collapse
-
#metrics ⇒ Array<String>
Types of the metrics to report to this monitoring destination.
-
#monitored_resource ⇒ String
The monitored resource type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MonitoringDestination
constructor
A new instance of MonitoringDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MonitoringDestination
Returns a new instance of MonitoringDestination.
4590 4591 4592 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metrics ⇒ Array<String>
Types of the metrics to report to this monitoring destination. Each type must
be defined in Service.metrics section.
Corresponds to the JSON property metrics
4582 4583 4584 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4582 def metrics @metrics end |
#monitored_resource ⇒ String
The monitored resource type. The type must be defined in Service.
monitored_resources section.
Corresponds to the JSON property monitoredResource
4588 4589 4590 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4588 def monitored_resource @monitored_resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4595 4596 4597 4598 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4595 def update!(**args) @metrics = args[:metrics] if args.key?(:metrics) @monitored_resource = args[:monitored_resource] if args.key?(:monitored_resource) end |