Class: Google::Apis::ServiceusageV1::PythonSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Settings for Python client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PythonSettings

Returns a new instance of PythonSettings.



5033
5034
5035
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commonGoogle::Apis::ServiceusageV1::CommonLanguageSettings

Required information for every language. Corresponds to the JSON property common



5025
5026
5027
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5025

def common
  @common
end

#experimental_featuresGoogle::Apis::ServiceusageV1::ExperimentalFeatures

Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default. Corresponds to the JSON property experimentalFeatures



5031
5032
5033
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5031

def experimental_features
  @experimental_features
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5038
5039
5040
5041
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5038

def update!(**args)
  @common = args[:common] if args.key?(:common)
  @experimental_features = args[:experimental_features] if args.key?(:experimental_features)
end