Class: Google::Apis::ServiceusageV1::QuotaLimit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

QuotaLimit defines a specific limit that applies over a specified duration for a limit type. There can be at most one limit for a duration and limit type combination defined within a QuotaGroup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaLimit

Returns a new instance of QuotaLimit.



5183
5184
5185
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_limitFixnum

Default number of tokens that can be consumed during the specified duration. This is the number of tokens assigned when a client application developer activates the service for his/her project. Specifying a value of 0 will block all requests. This can be used if you are provisioning quota to selected consumers and blocking others. Similarly, a value of -1 will indicate an unlimited quota. No other negative values are allowed. Used by group-based quotas only. Corresponds to the JSON property defaultLimit

Returns:

  • (Fixnum)


5103
5104
5105
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5103

def default_limit
  @default_limit
end

#descriptionString

Optional. User-visible, extended description for this quota limit. Should be used only when more context is needed to understand this limit than provided by the limit's display name (see: display_name). Corresponds to the JSON property description

Returns:

  • (String)


5110
5111
5112
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5110

def description
  @description
end

#display_nameString

User-visible display name for this limit. Optional. If not set, the UI will provide a default display name based on the quota configuration. This field can be used to override the default display name generated from the configuration. Corresponds to the JSON property displayName

Returns:

  • (String)


5118
5119
5120
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5118

def display_name
  @display_name
end

#durationString

Duration of this limit in textual notation. Must be "100s" or "1d". Used by group-based quotas only. Corresponds to the JSON property duration

Returns:

  • (String)


5124
5125
5126
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5124

def duration
  @duration
end

#free_tierFixnum

Free tier value displayed in the Developers Console for this limit. The free tier is the number of tokens that will be subtracted from the billed amount when billing is enabled. This field can only be set on a limit with duration " 1d", in a billable group; it is invalid on any other limit. If this field is not set, it defaults to 0, indicating that there is no free tier for this service. Used by group-based quotas only. Corresponds to the JSON property freeTier

Returns:

  • (Fixnum)


5134
5135
5136
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5134

def free_tier
  @free_tier
end

#max_limitFixnum

Maximum number of tokens that can be consumed during the specified duration. Client application developers can override the default limit up to this maximum. If specified, this value cannot be set to a value less than the default limit. If not specified, it is set to the default limit. To allow clients to apply overrides with no upper bound, set this to -1, indicating unlimited maximum quota. Used by group-based quotas only. Corresponds to the JSON property maxLimit

Returns:

  • (Fixnum)


5144
5145
5146
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5144

def max_limit
  @max_limit
end

#metricString

The name of the metric this quota limit applies to. The quota limits with the same metric will be checked together during runtime. The metric must be defined within the service config. Corresponds to the JSON property metric

Returns:

  • (String)


5151
5152
5153
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5151

def metric
  @metric
end

#nameString

Name of the quota limit. The name must be provided, and it must be unique within the service. The name can only include alphanumeric characters as well as '-'. The maximum length of the limit name is 64 characters. Corresponds to the JSON property name

Returns:

  • (String)


5158
5159
5160
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5158

def name
  @name
end

#traffic_sourceString

Optional. This is only informational, the logic to allocate the quota to the correct metric (such as in metric_rules) should identify which quota metrics to allocate to. Corresponds to the JSON property trafficSource

Returns:

  • (String)


5165
5166
5167
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5165

def traffic_source
  @traffic_source
end

#unitString

Specify the unit of the quota limit. It uses the same syntax as MetricDescriptor.unit. The supported unit kinds are determined by the quota backend system. Here are some examples: * "1/min/project" for quota per minute per project. Note: the order of unit components is insignificant. The " 1" at the beginning is required to follow the metric unit syntax. Corresponds to the JSON property unit

Returns:

  • (String)


5174
5175
5176
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5174

def unit
  @unit
end

#valuesHash<String,Fixnum>

Tiered limit values. You must specify this as a key:value pair, with an integer value that is the maximum number of requests allowed for the specified unit. Currently only STANDARD is supported. Corresponds to the JSON property values

Returns:

  • (Hash<String,Fixnum>)


5181
5182
5183
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5181

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5188

def update!(**args)
  @default_limit = args[:default_limit] if args.key?(:default_limit)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @duration = args[:duration] if args.key?(:duration)
  @free_tier = args[:free_tier] if args.key?(:free_tier)
  @max_limit = args[:max_limit] if args.key?(:max_limit)
  @metric = args[:metric] if args.key?(:metric)
  @name = args[:name] if args.key?(:name)
  @traffic_source = args[:traffic_source] if args.key?(:traffic_source)
  @unit = args[:unit] if args.key?(:unit)
  @values = args[:values] if args.key?(:values)
end