Class: Google::Apis::ServiceusageV1::QuotaOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

A quota override

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaOverride

Returns a new instance of QuotaOverride.



5111
5112
5113
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_override_ancestorString

The resource name of the ancestor that requested the override. For example: organizations/12345 or folders/67890. Used by admin overrides only. Corresponds to the JSON property adminOverrideAncestor

Returns:

  • (String)


5059
5060
5061
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5059

def admin_override_ancestor
  @admin_override_ancestor
end

#dimensionsHash<String,String>

If this map is nonempty, then this override applies only to specific values for dimensions defined in the limit unit. For example, an override on a limit with the unit 1/project/regioncould contain an entry with the key ` region` and the value `us-east-1`; the override is only applied to quota consumed in that region. This map has the following restrictions: * Keys that are not defined in the limit's unit are not valid keys. Any string appearing inbracketsin the unit (besidesprojectoruser``) is a defined key.

  • project is not a valid key; the project is already specified in the parent resource name. * user is not a valid key; the API does not support quota overrides that apply only to a specific user. * If region appears as a key, its value must be a valid Cloud region. * If zone appears as a key, its value must be a valid Cloud zone. * If any valid key other than region or zone appears in the map, then all valid keys other than region or zone must also appear in the map. Corresponds to the JSON property dimensions

Returns:

  • (Hash<String,String>)


5077
5078
5079
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5077

def dimensions
  @dimensions
end

#metricString

The name of the metric to which this override applies. An example name would be: compute.googleapis.com/cpus Corresponds to the JSON property metric

Returns:

  • (String)


5083
5084
5085
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5083

def metric
  @metric
end

#nameString

The resource name of the override. This name is generated by the server when the override is created. Example names would be: projects/123/services/ compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/ limits/%2Fproject%2Fregion/adminOverrides/4a3f2c1d projects/123/services/ compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/ limits/%2Fproject%2Fregion/consumerOverrides/4a3f2c1d The resource name is intended to be opaque and should not be parsed for its component strings, since its representation could change in the future. Corresponds to the JSON property name

Returns:

  • (String)


5095
5096
5097
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5095

def name
  @name
end

#override_valueFixnum

The overriding quota limit value. Can be any nonnegative integer, or -1 ( unlimited quota). Corresponds to the JSON property overrideValue

Returns:

  • (Fixnum)


5101
5102
5103
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5101

def override_value
  @override_value
end

#unitString

The limit unit of the limit to which this override applies. An example unit would be: 1/project/regionNote thatprojectandregionare not placeholders in this example; the literal charactersand`occur in the string. Corresponds to the JSON propertyunit`

Returns:

  • (String)


5109
5110
5111
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5109

def unit
  @unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5116
5117
5118
5119
5120
5121
5122
5123
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5116

def update!(**args)
  @admin_override_ancestor = args[:admin_override_ancestor] if args.key?(:admin_override_ancestor)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @metric = args[:metric] if args.key?(:metric)
  @name = args[:name] if args.key?(:name)
  @override_value = args[:override_value] if args.key?(:override_value)
  @unit = args[:unit] if args.key?(:unit)
end