Class: Google::Apis::ServiceusageV1::SystemParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Define a parameter's name and location. The parameter may be passed as either an HTTP header or a URL query parameter, and if both are passed the behavior is implementation-dependent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SystemParameter

Returns a new instance of SystemParameter.



5348
5349
5350
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_headerString

Define the HTTP header name to use for the parameter. It is case insensitive. Corresponds to the JSON property httpHeader

Returns:

  • (String)


5335
5336
5337
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5335

def http_header
  @http_header
end

#nameString

Define the name of the parameter, such as "api_key" . It is case sensitive. Corresponds to the JSON property name

Returns:

  • (String)


5340
5341
5342
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5340

def name
  @name
end

#url_query_parameterString

Define the URL query parameter name to use for the parameter. It is case sensitive. Corresponds to the JSON property urlQueryParameter

Returns:

  • (String)


5346
5347
5348
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5346

def url_query_parameter
  @url_query_parameter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5353
5354
5355
5356
5357
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5353

def update!(**args)
  @http_header = args[:http_header] if args.key?(:http_header)
  @name = args[:name] if args.key?(:name)
  @url_query_parameter = args[:url_query_parameter] if args.key?(:url_query_parameter)
end