Class: Google::Apis::ServiceusageV1::UsageRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Usage configuration rules for the service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsageRule

Returns a new instance of UsageRule.



5746
5747
5748
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_unregistered_callsBoolean Also known as: allow_unregistered_calls?

Use this rule to configure unregistered calls for the service. Unregistered calls are calls that do not contain consumer project identity. (Example: calls that do not contain an API key). WARNING: By default, API methods do not allow unregistered calls, and each method call must be identified by a consumer project identity. Corresponds to the JSON property allowUnregisteredCalls

Returns:

  • (Boolean)


5728
5729
5730
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5728

def allow_unregistered_calls
  @allow_unregistered_calls
end

#selectorString

Selects the methods to which this rule applies. Use '*' to indicate all methods in all APIs. Refer to selector for syntax details. Corresponds to the JSON property selector

Returns:

  • (String)


5735
5736
5737
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5735

def selector
  @selector
end

#skip_service_controlBoolean Also known as: skip_service_control?

If true, the selected method should skip service control and the control plane features, such as quota and billing, will not be available. This flag is used by Google Cloud Endpoints to bypass checks for internal methods, such as service health check methods. Corresponds to the JSON property skipServiceControl

Returns:

  • (Boolean)


5743
5744
5745
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5743

def skip_service_control
  @skip_service_control
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5751
5752
5753
5754
5755
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5751

def update!(**args)
  @allow_unregistered_calls = args[:allow_unregistered_calls] if args.key?(:allow_unregistered_calls)
  @selector = args[:selector] if args.key?(:selector)
  @skip_service_control = args[:skip_service_control] if args.key?(:skip_service_control)
end