Class: Google::Apis::ServiceusageV1::Api
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::Api
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
Api is a light-weight descriptor for an API Interface. Interfaces are also described as "protocol buffer services" in some contexts, such as by the " service" keyword in a .proto file, but they are different from API Services, which represent a concrete implementation of an interface as opposed to simply a description of methods and bindings. They are also sometimes simply referred to as "APIs" in other contexts, such as the name of this message itself. See https://cloud.google.com/apis/design/glossary for detailed terminology. New usages of this message as an alternative to ServiceDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#methods_prop ⇒ Array<Google::Apis::ServiceusageV1::MethodProp>
The methods of this interface, in unspecified order.
-
#mixins ⇒ Array<Google::Apis::ServiceusageV1::Mixin>
Included interfaces.
-
#name ⇒ String
The fully qualified name of this interface, including package name followed by the interface's simple name.
-
#options ⇒ Array<Google::Apis::ServiceusageV1::Option>
Any metadata attached to the interface.
-
#source_context ⇒ Google::Apis::ServiceusageV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax of the service.
-
#version ⇒ String
A version string for this interface.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Api
constructor
A new instance of Api.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Api
Returns a new instance of Api.
298 299 300 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
247 248 249 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 247 def edition @edition end |
#methods_prop ⇒ Array<Google::Apis::ServiceusageV1::MethodProp>
The methods of this interface, in unspecified order.
Corresponds to the JSON property methods
252 253 254 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 252 def methods_prop @methods_prop end |
#mixins ⇒ Array<Google::Apis::ServiceusageV1::Mixin>
Included interfaces. See Mixin.
Corresponds to the JSON property mixins
257 258 259 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 257 def mixins @mixins end |
#name ⇒ String
The fully qualified name of this interface, including package name followed by
the interface's simple name.
Corresponds to the JSON property name
263 264 265 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 263 def name @name end |
#options ⇒ Array<Google::Apis::ServiceusageV1::Option>
Any metadata attached to the interface.
Corresponds to the JSON property options
268 269 270 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 268 def @options end |
#source_context ⇒ Google::Apis::ServiceusageV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
274 275 276 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 274 def source_context @source_context end |
#syntax ⇒ String
The source syntax of the service.
Corresponds to the JSON property syntax
279 280 281 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 279 def syntax @syntax end |
#version ⇒ String
A version string for this interface. If specified, must have the form major-
version.minor-version, as in 1.10. If the minor version is omitted, it
defaults to zero. If the entire version field is empty, the major version is
derived from the package name, as outlined below. If the field is not empty,
the version in the package name will be verified to be consistent with what is
provided here. The versioning schema uses semantic versioning where the major version number indicates a breaking change and the minor
version an additive, non-breaking change. Both version numbers are signals to
users what to expect from different versions, and should be carefully chosen
based on the product plan. The major version is also reflected in the package
name of the interface, which must end in v, as in google.feature.v1. For
major versions 0 and 1, the suffix can be omitted. Zero major versions must
only be used for experimental, non-GA interfaces.
Corresponds to the JSON property version
296 297 298 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 296 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
303 304 305 306 307 308 309 310 311 312 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 303 def update!(**args) @edition = args[:edition] if args.key?(:edition) @methods_prop = args[:methods_prop] if args.key?(:methods_prop) @mixins = args[:mixins] if args.key?(:mixins) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) @version = args[:version] if args.key?(:version) end |