Class: Google::Apis::ServiceusageV1::BatchingConfigProto
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::BatchingConfigProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
BatchingConfigProto defines the batching configuration for an API method.
Instance Attribute Summary collapse
-
#batch_descriptor ⇒ Google::Apis::ServiceusageV1::BatchingDescriptorProto
BatchingDescriptorProtospecifies the fields of the request message to be used for batching, and, optionally, the fields of the response message to be used for demultiplexing. -
#thresholds ⇒ Google::Apis::ServiceusageV1::BatchingSettingsProto
BatchingSettingsProtospecifies a set of batching thresholds, each of which acts as a trigger to send a batch of messages as a request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchingConfigProto
constructor
A new instance of BatchingConfigProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchingConfigProto
Returns a new instance of BatchingConfigProto.
793 794 795 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_descriptor ⇒ Google::Apis::ServiceusageV1::BatchingDescriptorProto
BatchingDescriptorProto specifies the fields of the request message to be
used for batching, and, optionally, the fields of the response message to be
used for demultiplexing.
Corresponds to the JSON property batchDescriptor
784 785 786 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 784 def batch_descriptor @batch_descriptor end |
#thresholds ⇒ Google::Apis::ServiceusageV1::BatchingSettingsProto
BatchingSettingsProto specifies a set of batching thresholds, each of which
acts as a trigger to send a batch of messages as a request. At least one
threshold must be positive nonzero.
Corresponds to the JSON property thresholds
791 792 793 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 791 def thresholds @thresholds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
798 799 800 801 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 798 def update!(**args) @batch_descriptor = args[:batch_descriptor] if args.key?(:batch_descriptor) @thresholds = args[:thresholds] if args.key?(:thresholds) end |