Class: Google::Apis::ServiceusageV1::BatchingSettingsProto
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::BatchingSettingsProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
BatchingSettingsProto specifies a set of batching thresholds, each of which
acts as a trigger to send a batch of messages as a request. At least one
threshold must be positive nonzero.
Instance Attribute Summary collapse
-
#delay_threshold ⇒ String
The duration after which a batch should be sent, starting from the addition of the first message to that batch.
-
#element_count_limit ⇒ Fixnum
The maximum number of elements collected in a batch that could be accepted by server.
-
#element_count_threshold ⇒ Fixnum
The number of elements of a field collected into a batch which, if exceeded, causes the batch to be sent.
-
#flow_control_byte_limit ⇒ Fixnum
The maximum size of data allowed by flow control.
-
#flow_control_element_limit ⇒ Fixnum
The maximum number of elements allowed by flow control.
-
#flow_control_limit_exceeded_behavior ⇒ String
The behavior to take when the flow control limit is exceeded.
-
#request_byte_limit ⇒ Fixnum
The maximum size of the request that could be accepted by server.
-
#request_byte_threshold ⇒ Fixnum
The aggregated size of the batched field which, if exceeded, causes the batch to be sent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchingSettingsProto
constructor
A new instance of BatchingSettingsProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchingSettingsProto
Returns a new instance of BatchingSettingsProto.
892 893 894 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 892 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delay_threshold ⇒ String
The duration after which a batch should be sent, starting from the addition of
the first message to that batch.
Corresponds to the JSON property delayThreshold
851 852 853 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 851 def delay_threshold @delay_threshold end |
#element_count_limit ⇒ Fixnum
The maximum number of elements collected in a batch that could be accepted by
server.
Corresponds to the JSON property elementCountLimit
857 858 859 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 857 def element_count_limit @element_count_limit end |
#element_count_threshold ⇒ Fixnum
The number of elements of a field collected into a batch which, if exceeded,
causes the batch to be sent.
Corresponds to the JSON property elementCountThreshold
863 864 865 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 863 def element_count_threshold @element_count_threshold end |
#flow_control_byte_limit ⇒ Fixnum
The maximum size of data allowed by flow control.
Corresponds to the JSON property flowControlByteLimit
868 869 870 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 868 def flow_control_byte_limit @flow_control_byte_limit end |
#flow_control_element_limit ⇒ Fixnum
The maximum number of elements allowed by flow control.
Corresponds to the JSON property flowControlElementLimit
873 874 875 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 873 def flow_control_element_limit @flow_control_element_limit end |
#flow_control_limit_exceeded_behavior ⇒ String
The behavior to take when the flow control limit is exceeded.
Corresponds to the JSON property flowControlLimitExceededBehavior
878 879 880 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 878 def flow_control_limit_exceeded_behavior @flow_control_limit_exceeded_behavior end |
#request_byte_limit ⇒ Fixnum
The maximum size of the request that could be accepted by server.
Corresponds to the JSON property requestByteLimit
883 884 885 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 883 def request_byte_limit @request_byte_limit end |
#request_byte_threshold ⇒ Fixnum
The aggregated size of the batched field which, if exceeded, causes the batch
to be sent. This size is computed by aggregating the sizes of the request
field to be batched, not of the entire request message.
Corresponds to the JSON property requestByteThreshold
890 891 892 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 890 def request_byte_threshold @request_byte_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
897 898 899 900 901 902 903 904 905 906 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 897 def update!(**args) @delay_threshold = args[:delay_threshold] if args.key?(:delay_threshold) @element_count_limit = args[:element_count_limit] if args.key?(:element_count_limit) @element_count_threshold = args[:element_count_threshold] if args.key?(:element_count_threshold) @flow_control_byte_limit = args[:flow_control_byte_limit] if args.key?(:flow_control_byte_limit) @flow_control_element_limit = args[:flow_control_element_limit] if args.key?(:flow_control_element_limit) @flow_control_limit_exceeded_behavior = args[:flow_control_limit_exceeded_behavior] if args.key?(:flow_control_limit_exceeded_behavior) @request_byte_limit = args[:request_byte_limit] if args.key?(:request_byte_limit) @request_byte_threshold = args[:request_byte_threshold] if args.key?(:request_byte_threshold) end |