Class: Google::Apis::ServiceusageV1::ConsumerPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::ConsumerPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#enable_rules ⇒ Array<Google::Apis::ServiceusageV1::EnableRule>
Enable rules define usable services and service groups.
-
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for concurrency control.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
The last-modified time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumerPolicy
constructor
A new instance of ConsumerPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumerPolicy
Returns a new instance of ConsumerPolicy.
1175 1176 1177 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a policy
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. AIP-
128
Corresponds to the JSON property annotations
1149 1150 1151 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1149 def annotations @annotations end |
#enable_rules ⇒ Array<Google::Apis::ServiceusageV1::EnableRule>
Enable rules define usable services and service groups.
Corresponds to the JSON property enableRules
1154 1155 1156 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1154 def enable_rules @enable_rules end |
#etag ⇒ String
An opaque tag indicating the current version of the policy, used for
concurrency control.
Corresponds to the JSON property etag
1160 1161 1162 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1160 def etag @etag end |
#name ⇒ String
Output only. The resource name of the policy. We only allow consumer policy
name as default for now: projects/12345/consumerPolicies/default, folders/
12345/consumerPolicies/default, organizations/12345/consumerPolicies/default
.
Corresponds to the JSON property name
1168 1169 1170 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1168 def name @name end |
#update_time ⇒ String
The last-modified time.
Corresponds to the JSON property updateTime
1173 1174 1175 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1173 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1180 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @enable_rules = args[:enable_rules] if args.key?(:enable_rules) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |