Class: Google::Apis::ServiceusageV1::ContentSecurityPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Content Security Policy contains the content security related policy of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentSecurityPolicy

Returns a new instance of ContentSecurityPolicy.



1191
1192
1193
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mcp_content_securityGoogle::Apis::ServiceusageV1::ContentSecurity

ContentSecurity defines the content security related fields of a MCP policy. Corresponds to the JSON property mcpContentSecurity



1180
1181
1182
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1180

def mcp_content_security
  @mcp_content_security
end

#nameString

Output only. The resource name of the policy. Only the default policy is supported. We allow the following formats: projects/PROJECT_NUMBER/ contentSecurityPolicies/default, projects/PROJECT_ID/ contentSecurityPolicies/default, We only support project level content security policy for now. Corresponds to the JSON property name

Returns:

  • (String)


1189
1190
1191
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1189

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1196
1197
1198
1199
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1196

def update!(**args)
  @mcp_content_security = args[:mcp_content_security] if args.key?(:mcp_content_security)
  @name = args[:name] if args.key?(:name)
end