Class: Google::Apis::ServiceusageV1::ContextRule
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::ContextRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
A context rule provides information about the context for an individual API element.
Instance Attribute Summary collapse
-
#allowed_request_extensions ⇒ Array<String>
A list of full type names or extension IDs of extensions allowed in grpc side channel from client to backend.
-
#allowed_response_extensions ⇒ Array<String>
A list of full type names or extension IDs of extensions allowed in grpc side channel from backend to client.
-
#provided ⇒ Array<String>
A list of full type names of provided contexts.
-
#requested ⇒ Array<String>
A list of full type names of requested contexts, only the requested context will be made available to the backend.
-
#selector ⇒ String
Selects the methods to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContextRule
constructor
A new instance of ContextRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContextRule
Returns a new instance of ContextRule.
1328 1329 1330 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1328 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_request_extensions ⇒ Array<String>
A list of full type names or extension IDs of extensions allowed in grpc side
channel from client to backend.
Corresponds to the JSON property allowedRequestExtensions
1302 1303 1304 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1302 def allowed_request_extensions @allowed_request_extensions end |
#allowed_response_extensions ⇒ Array<String>
A list of full type names or extension IDs of extensions allowed in grpc side
channel from backend to client.
Corresponds to the JSON property allowedResponseExtensions
1308 1309 1310 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1308 def allowed_response_extensions @allowed_response_extensions end |
#provided ⇒ Array<String>
A list of full type names of provided contexts. It is used to support
propagating HTTP headers and ETags from the response extension.
Corresponds to the JSON property provided
1314 1315 1316 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1314 def provided @provided end |
#requested ⇒ Array<String>
A list of full type names of requested contexts, only the requested context
will be made available to the backend.
Corresponds to the JSON property requested
1320 1321 1322 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1320 def requested @requested end |
#selector ⇒ String
Selects the methods to which this rule applies. Refer to selector for syntax
details.
Corresponds to the JSON property selector
1326 1327 1328 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1326 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1333 1334 1335 1336 1337 1338 1339 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1333 def update!(**args) @allowed_request_extensions = args[:allowed_request_extensions] if args.key?(:allowed_request_extensions) @allowed_response_extensions = args[:allowed_response_extensions] if args.key?(:allowed_response_extensions) @provided = args[:provided] if args.key?(:provided) @requested = args[:requested] if args.key?(:requested) @selector = args[:selector] if args.key?(:selector) end |