Class: Google::Apis::ServiceusageV1::DisableServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Request message for the DisableService method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DisableServiceRequest

Returns a new instance of DisableServiceRequest.



1519
1520
1521
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1519

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_if_service_has_usageString

Defines the behavior for checking service usage when disabling a service. Corresponds to the JSON property checkIfServiceHasUsage

Returns:

  • (String)


1508
1509
1510
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1508

def check_if_service_has_usage
  @check_if_service_has_usage
end

#disable_dependent_servicesBoolean Also known as: disable_dependent_services?

Indicates if services that are enabled and which depend on this service should also be disabled. If not set, an error will be generated if any enabled services depend on the service to be disabled. When set, the service, and any enabled services that depend on it, will be disabled together. Corresponds to the JSON property disableDependentServices

Returns:

  • (Boolean)


1516
1517
1518
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1516

def disable_dependent_services
  @disable_dependent_services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1524
1525
1526
1527
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1524

def update!(**args)
  @check_if_service_has_usage = args[:check_if_service_has_usage] if args.key?(:check_if_service_has_usage)
  @disable_dependent_services = args[:disable_dependent_services] if args.key?(:disable_dependent_services)
end