Class: Google::Apis::ServiceusageV1::DisableServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Request message for the DisableService method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DisableServiceRequest

Returns a new instance of DisableServiceRequest.



1483
1484
1485
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_if_service_has_usageString

Defines the behavior for checking service usage when disabling a service. Corresponds to the JSON property checkIfServiceHasUsage

Returns:

  • (String)


1472
1473
1474
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1472

def check_if_service_has_usage
  @check_if_service_has_usage
end

#disable_dependent_servicesBoolean Also known as: disable_dependent_services?

Indicates if services that are enabled and which depend on this service should also be disabled. If not set, an error will be generated if any enabled services depend on the service to be disabled. When set, the service, and any enabled services that depend on it, will be disabled together. Corresponds to the JSON property disableDependentServices

Returns:

  • (Boolean)


1480
1481
1482
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1480

def disable_dependent_services
  @disable_dependent_services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1488
1489
1490
1491
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1488

def update!(**args)
  @check_if_service_has_usage = args[:check_if_service_has_usage] if args.key?(:check_if_service_has_usage)
  @disable_dependent_services = args[:disable_dependent_services] if args.key?(:disable_dependent_services)
end