Class: Google::Apis::ServiceusageV1::EnableRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

The consumer policy rule that defines usable services and service groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnableRule

Returns a new instance of EnableRule.



1825
1826
1827
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_typeString

Client and resource project enable type. Corresponds to the JSON property enableType

Returns:

  • (String)


1803
1804
1805
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1803

def enable_type
  @enable_type
end

#groupsArray<String>

DEPRECATED: Please use field values. Service group should have prefix groups/. The names of the service groups that are enabled (Not Implemented). Example: groups/googleServices. Corresponds to the JSON property groups

Returns:

  • (Array<String>)


1810
1811
1812
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1810

def groups
  @groups
end

#servicesArray<String>

DEPRECATED: Please use field values. Service should have prefix services/. The names of the services that are enabled. Example: storage.googleapis.com. Corresponds to the JSON property services

Returns:

  • (Array<String>)


1816
1817
1818
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1816

def services
  @services
end

#valuesArray<String>

The names of the services or service groups that are enabled. Example: services/storage.googleapis.com, groups/googleServices, groups/allServices . Corresponds to the JSON property values

Returns:

  • (Array<String>)


1823
1824
1825
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1823

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1830
1831
1832
1833
1834
1835
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1830

def update!(**args)
  @enable_type = args[:enable_type] if args.key?(:enable_type)
  @groups = args[:groups] if args.key?(:groups)
  @services = args[:services] if args.key?(:services)
  @values = args[:values] if args.key?(:values)
end