Class: Google::Apis::ServiceusageV1::EnableRule
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::EnableRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
The consumer policy rule that defines usable services and service groups.
Instance Attribute Summary collapse
-
#enable_type ⇒ String
Client and resource project enable type.
-
#groups ⇒ Array<String>
DEPRECATED: Please use field
values. -
#services ⇒ Array<String>
DEPRECATED: Please use field
values. -
#values ⇒ Array<String>
The names of the services or service groups that are enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnableRule
constructor
A new instance of EnableRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnableRule
Returns a new instance of EnableRule.
1789 1790 1791 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1789 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_type ⇒ String
Client and resource project enable type.
Corresponds to the JSON property enableType
1767 1768 1769 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1767 def enable_type @enable_type end |
#groups ⇒ Array<String>
DEPRECATED: Please use field values. Service group should have prefix
groups/. The names of the service groups that are enabled (Not Implemented).
Example: groups/googleServices.
Corresponds to the JSON property groups
1774 1775 1776 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1774 def groups @groups end |
#services ⇒ Array<String>
DEPRECATED: Please use field values. Service should have prefix services/.
The names of the services that are enabled. Example: storage.googleapis.com.
Corresponds to the JSON property services
1780 1781 1782 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1780 def services @services end |
#values ⇒ Array<String>
The names of the services or service groups that are enabled. Example:
services/storage.googleapis.com, groups/googleServices, groups/allServices
.
Corresponds to the JSON property values
1787 1788 1789 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1787 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1794 1795 1796 1797 1798 1799 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1794 def update!(**args) @enable_type = args[:enable_type] if args.key?(:enable_type) @groups = args[:groups] if args.key?(:groups) @services = args[:services] if args.key?(:services) @values = args[:values] if args.key?(:values) end |