Class: Google::Apis::ServiceusageV1::EnableServiceResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Response message for the EnableService method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnableServiceResponse

Returns a new instance of EnableServiceResponse.



1862
1863
1864
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceGoogle::Apis::ServiceusageV1::GoogleApiServiceusageV1Service

A service that is available for use by the consumer. Corresponds to the JSON property service



1860
1861
1862
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1860

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1867
1868
1869
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1867

def update!(**args)
  @service = args[:service] if args.key?(:service)
end