Class: Google::Apis::ServiceusageV1::Enum

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Enum

Returns a new instance of Enum.



1933
1934
1935
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


1905
1906
1907
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1905

def edition
  @edition
end

#enumvalueArray<Google::Apis::ServiceusageV1::EnumValue>

Enum value definitions. Corresponds to the JSON property enumvalue



1910
1911
1912
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1910

def enumvalue
  @enumvalue
end

#nameString

Enum type name. Corresponds to the JSON property name

Returns:

  • (String)


1915
1916
1917
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1915

def name
  @name
end

#optionsArray<Google::Apis::ServiceusageV1::Option>

Protocol buffer options. Corresponds to the JSON property options



1920
1921
1922
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1920

def options
  @options
end

#source_contextGoogle::Apis::ServiceusageV1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



1926
1927
1928
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1926

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


1931
1932
1933
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1931

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1938
1939
1940
1941
1942
1943
1944
1945
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1938

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @enumvalue = args[:enumvalue] if args.key?(:enumvalue)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end