Class: Google::Apis::ServiceusageV1::EnumValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnumValue

Returns a new instance of EnumValue.



2007
2008
2009
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Enum value name. Corresponds to the JSON property name

Returns:

  • (String)


1995
1996
1997
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1995

def name
  @name
end

#numberFixnum

Enum value number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


2000
2001
2002
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2000

def number
  @number
end

#optionsArray<Google::Apis::ServiceusageV1::Option>

Protocol buffer options. Corresponds to the JSON property options



2005
2006
2007
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2005

def options
  @options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2012
2013
2014
2015
2016
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2012

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @options = args[:options] if args.key?(:options)
end