Class: Google::Apis::ServiceusageV1::EnumValue
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::EnumValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#name ⇒ String
Enum value name.
-
#number ⇒ Fixnum
Enum value number.
-
#options ⇒ Array<Google::Apis::ServiceusageV1::Option>
Protocol buffer options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnumValue
constructor
A new instance of EnumValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnumValue
Returns a new instance of EnumValue.
1971 1972 1973 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Enum value name.
Corresponds to the JSON property name
1959 1960 1961 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1959 def name @name end |
#number ⇒ Fixnum
Enum value number.
Corresponds to the JSON property number
1964 1965 1966 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1964 def number @number end |
#options ⇒ Array<Google::Apis::ServiceusageV1::Option>
Protocol buffer options.
Corresponds to the JSON property options
1969 1970 1971 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1969 def @options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1976 1977 1978 1979 1980 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 1976 def update!(**args) @name = args[:name] if args.key?(:name) @number = args[:number] if args.key?(:number) @options = args[:options] if args.key?(:options) end |