Class: Google::Apis::ServiceusageV1::Field
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::Field
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#cardinality ⇒ String
The field cardinality.
-
#default_value ⇒ String
The string value of the default value of this field.
-
#json_name ⇒ String
The field JSON name.
-
#kind ⇒ String
The field type.
-
#name ⇒ String
The field name.
-
#number ⇒ Fixnum
The field number.
-
#oneof_index ⇒ Fixnum
The index of the field type in
Type.oneofs, for message or enumeration types. -
#options ⇒ Array<Google::Apis::ServiceusageV1::Option>
The protocol buffer options.
-
#packed ⇒ Boolean
(also: #packed?)
Whether to use alternative packed wire representation.
-
#type_url ⇒ String
The field type URL, without the scheme, for message or enumeration types.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Field
constructor
A new instance of Field.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Field
Returns a new instance of Field.
2123 2124 2125 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cardinality ⇒ String
The field cardinality.
Corresponds to the JSON property cardinality
2073 2074 2075 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2073 def cardinality @cardinality end |
#default_value ⇒ String
The string value of the default value of this field. Proto2 syntax only.
Corresponds to the JSON property defaultValue
2078 2079 2080 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2078 def default_value @default_value end |
#json_name ⇒ String
The field JSON name.
Corresponds to the JSON property jsonName
2083 2084 2085 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2083 def json_name @json_name end |
#kind ⇒ String
The field type.
Corresponds to the JSON property kind
2088 2089 2090 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2088 def kind @kind end |
#name ⇒ String
The field name.
Corresponds to the JSON property name
2093 2094 2095 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2093 def name @name end |
#number ⇒ Fixnum
The field number.
Corresponds to the JSON property number
2098 2099 2100 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2098 def number @number end |
#oneof_index ⇒ Fixnum
The index of the field type in Type.oneofs, for message or enumeration types.
The first type has index 1; zero means the type is not in the list.
Corresponds to the JSON property oneofIndex
2104 2105 2106 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2104 def oneof_index @oneof_index end |
#options ⇒ Array<Google::Apis::ServiceusageV1::Option>
The protocol buffer options.
Corresponds to the JSON property options
2109 2110 2111 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2109 def @options end |
#packed ⇒ Boolean Also known as: packed?
Whether to use alternative packed wire representation.
Corresponds to the JSON property packed
2114 2115 2116 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2114 def packed @packed end |
#type_url ⇒ String
The field type URL, without the scheme, for message or enumeration types.
Example: "type.googleapis.com/google.protobuf.Timestamp".
Corresponds to the JSON property typeUrl
2121 2122 2123 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2121 def type_url @type_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2128 def update!(**args) @cardinality = args[:cardinality] if args.key?(:cardinality) @default_value = args[:default_value] if args.key?(:default_value) @json_name = args[:json_name] if args.key?(:json_name) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @number = args[:number] if args.key?(:number) @oneof_index = args[:oneof_index] if args.key?(:oneof_index) @options = args[:options] if args.key?(:options) @packed = args[:packed] if args.key?(:packed) @type_url = args[:type_url] if args.key?(:type_url) end |