Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaAnalysis
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
A message to group the analysis information.
Instance Attribute Summary collapse
-
#analysis_result ⇒ Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaAnalysisResult
An analysis result including blockers and warnings.
-
#analysis_type ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#service ⇒ String
The names of the service that has analysis result of warnings or blockers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2alphaAnalysis
constructor
A new instance of GoogleApiServiceusageV2alphaAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2alphaAnalysis
Returns a new instance of GoogleApiServiceusageV2alphaAnalysis.
2870 2871 2872 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_result ⇒ Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaAnalysisResult
An analysis result including blockers and warnings.
Corresponds to the JSON property analysisResult
2851 2852 2853 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2851 def analysis_result @analysis_result end |
#analysis_type ⇒ String
Output only. The type of analysis.
Corresponds to the JSON property analysisType
2856 2857 2858 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2856 def analysis_type @analysis_type end |
#display_name ⇒ String
Output only. The user friendly display name of the analysis type. E.g. service
dependency analysis, service resource usage analysis, etc.
Corresponds to the JSON property displayName
2862 2863 2864 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2862 def display_name @display_name end |
#service ⇒ String
The names of the service that has analysis result of warnings or blockers.
Example: services/storage.googleapis.com.
Corresponds to the JSON property service
2868 2869 2870 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2868 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2875 2876 2877 2878 2879 2880 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2875 def update!(**args) @analysis_result = args[:analysis_result] if args.key?(:analysis_result) @analysis_type = args[:analysis_type] if args.key?(:analysis_type) @display_name = args[:display_name] if args.key?(:display_name) @service = args[:service] if args.key?(:service) end |