Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaAnalysisResult
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaAnalysisResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
An analysis result including blockers and warnings.
Instance Attribute Summary collapse
-
#blockers ⇒ Array<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaImpact>
Blocking information that would prevent the policy changes at runtime.
-
#warnings ⇒ Array<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaImpact>
Warning information indicating that the policy changes might be unsafe, but will not block the changes at runtime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2alphaAnalysisResult
constructor
A new instance of GoogleApiServiceusageV2alphaAnalysisResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2alphaAnalysisResult
Returns a new instance of GoogleApiServiceusageV2alphaAnalysisResult.
2898 2899 2900 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blockers ⇒ Array<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaImpact>
Blocking information that would prevent the policy changes at runtime.
Corresponds to the JSON property blockers
2890 2891 2892 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2890 def blockers @blockers end |
#warnings ⇒ Array<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaImpact>
Warning information indicating that the policy changes might be unsafe, but
will not block the changes at runtime.
Corresponds to the JSON property warnings
2896 2897 2898 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2896 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2903 2904 2905 2906 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2903 def update!(**args) @blockers = args[:blockers] if args.key?(:blockers) @warnings = args[:warnings] if args.key?(:warnings) end |