Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaConsumerPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Consumer Policy is a set of rules that define what services or service groups can be used for a cloud resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2alphaConsumerPolicy

Returns a new instance of GoogleApiServiceusageV2alphaConsumerPolicy.



2868
2869
2870
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a policy that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. AIP- 128 Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2835
2836
2837
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2835

def annotations
  @annotations
end

#create_timeString

Output only. The time the policy was created. For singleton policies, this is the first touch of the policy. Corresponds to the JSON property createTime

Returns:

  • (String)


2841
2842
2843
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2841

def create_time
  @create_time
end

#enable_rulesArray<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2alphaEnableRule>

Enable rules define usable services, groups, and categories. There can currently be at most one EnableRule. This restriction will be lifted in later releases. Corresponds to the JSON property enableRules



2848
2849
2850
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2848

def enable_rules
  @enable_rules
end

#etagString

Output only. An opaque tag indicating the current version of the policy, used for concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


2854
2855
2856
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2854

def etag
  @etag
end

#nameString

Output only. The resource name of the policy. Only the default policy is supported: projects/12345/consumerPolicies/default, folders/12345/ consumerPolicies/default, organizations/12345/consumerPolicies/default. Corresponds to the JSON property name

Returns:

  • (String)


2861
2862
2863
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2861

def name
  @name
end

#update_timeString

Output only. The time the policy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2866
2867
2868
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2866

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2873
2874
2875
2876
2877
2878
2879
2880
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2873

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @enable_rules = args[:enable_rules] if args.key?(:enable_rules)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end