Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysis
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
A message to group the analysis information.
Instance Attribute Summary collapse
-
#analysis_result ⇒ Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysisResult
An analysis result including blockers and warnings.
-
#analysis_type ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#service ⇒ String
The names of the service that has analysis result of warnings or blockers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiServiceusageV2betaAnalysis
constructor
A new instance of GoogleApiServiceusageV2betaAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiServiceusageV2betaAnalysis
Returns a new instance of GoogleApiServiceusageV2betaAnalysis.
2942 2943 2944 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2942 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_result ⇒ Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaAnalysisResult
An analysis result including blockers and warnings.
Corresponds to the JSON property analysisResult
2923 2924 2925 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2923 def analysis_result @analysis_result end |
#analysis_type ⇒ String
Output only. The type of analysis.
Corresponds to the JSON property analysisType
2928 2929 2930 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2928 def analysis_type @analysis_type end |
#display_name ⇒ String
Output only. The user friendly display name of the analysis type. E.g. service
dependency analysis, service resource usage analysis, etc.
Corresponds to the JSON property displayName
2934 2935 2936 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2934 def display_name @display_name end |
#service ⇒ String
The names of the service that has analysis result of warnings or blockers.
Example: services/storage.googleapis.com.
Corresponds to the JSON property service
2940 2941 2942 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2940 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2947 2948 2949 2950 2951 2952 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 2947 def update!(**args) @analysis_result = args[:analysis_result] if args.key?(:analysis_result) @analysis_type = args[:analysis_type] if args.key?(:analysis_type) @display_name = args[:display_name] if args.key?(:display_name) @service = args[:service] if args.key?(:service) end |