Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaImpact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

A message to group impacts of updating a policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaImpact

Returns a new instance of GoogleApiServiceusageV2betaImpact.



3108
3109
3110
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Output only. User friendly impact detail in a free form message. Corresponds to the JSON property detail

Returns:

  • (String)


3093
3094
3095
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3093

def detail
  @detail
end

#impact_typeString

Output only. The type of impact. Corresponds to the JSON property impactType

Returns:

  • (String)


3098
3099
3100
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3098

def impact_type
  @impact_type
end

#missing_dependencyString

Output only. This field will be populated only for the DEPENDENCY_MISSING_DEPENDENCIES impact type. Example: services/compute. googleapis.com. Impact.detail will be in format : missing service dependency: missing_dependency. Corresponds to the JSON property missingDependency

Returns:

  • (String)


3106
3107
3108
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3106

def missing_dependency
  @missing_dependency
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3113
3114
3115
3116
3117
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3113

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @impact_type = args[:impact_type] if args.key?(:impact_type)
  @missing_dependency = args[:missing_dependency] if args.key?(:missing_dependency)
end