Class: Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaMcpPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

MCP Consumer Policy is a set of rules that define MCP related policy for a cloud resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiServiceusageV2betaMcpPolicy

Returns a new instance of GoogleApiServiceusageV2betaMcpPolicy.



3174
3175
3176
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3174

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the policy was created. For singleton policies (such as the default policy), this is the first touch of the policy. Corresponds to the JSON property createTime

Returns:

  • (String)


3148
3149
3150
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3148

def create_time
  @create_time
end

#etagString

An opaque tag indicating the current version of the policy, used for concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


3154
3155
3156
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3154

def etag
  @etag
end

#mcp_enable_rulesArray<Google::Apis::ServiceusageV1::GoogleApiServiceusageV2betaMcpEnableRule>

McpEnableRules contains MCP enablement related rules. Corresponds to the JSON property mcpEnableRules



3159
3160
3161
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3159

def mcp_enable_rules
  @mcp_enable_rules
end

#nameString

Output only. The resource name of the policy. Only the default policy is supported. We allow the following formats: projects/PROJECT_NUMBER/ mcpPolicies/default, projects/PROJECT_ID/mcpPolicies/default, folders/ FOLDER_ID/mcpPolicies/default, organizations/ORG_ID/mcpPolicies/default. Corresponds to the JSON property name

Returns:

  • (String)


3167
3168
3169
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3167

def name
  @name
end

#update_timeString

Output only. The time the policy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3172
3173
3174
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3172

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3179
3180
3181
3182
3183
3184
3185
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3179

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @mcp_enable_rules = args[:mcp_enable_rules] if args.key?(:mcp_enable_rules)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end