Class: Google::Apis::ServiceusageV1::Impact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

A message to group impacts of updating a policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Impact

Returns a new instance of Impact.



3531
3532
3533
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Output only. User friendly impact detail in a free form message. Corresponds to the JSON property detail

Returns:

  • (String)


3512
3513
3514
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3512

def detail
  @detail
end

#impact_typeString

Output only. The type of impact. Corresponds to the JSON property impactType

Returns:

  • (String)


3517
3518
3519
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3517

def impact_type
  @impact_type
end

#parentString

The parent resource that the analysis is based on and the service name that the analysis is for. Example: projects/100/services/compute.googleapis.com, folders/101/services/compute.googleapis.comandorganizations/102/services/ compute.googleapis.com. Usually, the parent resource here is same as the parent resource of the analyzed policy. However, for some analysis types, the parent can be different. For example, for resource existence analysis, if the parent resource of the analyzed policy is a folder or an organization, the parent resource here can still be the project that contains the resources. Corresponds to the JSON propertyparent`

Returns:

  • (String)


3529
3530
3531
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3529

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3536
3537
3538
3539
3540
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3536

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @impact_type = args[:impact_type] if args.key?(:impact_type)
  @parent = args[:parent] if args.key?(:parent)
end