Class: Google::Apis::ServiceusageV1::Impact
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::Impact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
A message to group impacts of updating a policy.
Instance Attribute Summary collapse
-
#detail ⇒ String
Output only.
-
#impact_type ⇒ String
Output only.
-
#parent ⇒ String
The parent resource that the analysis is based on and the service name that the analysis is for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Impact
constructor
A new instance of Impact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Impact
Returns a new instance of Impact.
3501 3502 3503 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detail ⇒ String
Output only. User friendly impact detail in a free form message.
Corresponds to the JSON property detail
3482 3483 3484 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3482 def detail @detail end |
#impact_type ⇒ String
Output only. The type of impact.
Corresponds to the JSON property impactType
3487 3488 3489 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3487 def impact_type @impact_type end |
#parent ⇒ String
The parent resource that the analysis is based on and the service name that
the analysis is for. Example: projects/100/services/compute.googleapis.com,
folders/101/services/compute.googleapis.comandorganizations/102/services/
compute.googleapis.com. Usually, the parent resource here is same as the
parent resource of the analyzed policy. However, for some analysis types, the
parent can be different. For example, for resource existence analysis, if the
parent resource of the analyzed policy is a folder or an organization, the
parent resource here can still be the project that contains the resources.
Corresponds to the JSON propertyparent`
3499 3500 3501 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3499 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3506 3507 3508 3509 3510 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3506 def update!(**args) @detail = args[:detail] if args.key?(:detail) @impact_type = args[:impact_type] if args.key?(:impact_type) @parent = args[:parent] if args.key?(:parent) end |