Class: Google::Apis::ServiceusageV1::MethodProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodProp

Returns a new instance of MethodProp.



4029
4030
4031
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property edition

Returns:

  • (String)


3989
3990
3991
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3989

def edition
  @edition
end

#nameString

The simple name of this method. Corresponds to the JSON property name

Returns:

  • (String)


3994
3995
3996
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3994

def name
  @name
end

#optionsArray<Google::Apis::ServiceusageV1::Option>

Any metadata attached to the method. Corresponds to the JSON property options



3999
4000
4001
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 3999

def options
  @options
end

#request_streamingBoolean Also known as: request_streaming?

If true, the request is streamed. Corresponds to the JSON property requestStreaming

Returns:

  • (Boolean)


4004
4005
4006
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4004

def request_streaming
  @request_streaming
end

#request_type_urlString

A URL of the input message type. Corresponds to the JSON property requestTypeUrl

Returns:

  • (String)


4010
4011
4012
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4010

def request_type_url
  @request_type_url
end

#response_streamingBoolean Also known as: response_streaming?

If true, the response is streamed. Corresponds to the JSON property responseStreaming

Returns:

  • (Boolean)


4015
4016
4017
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4015

def response_streaming
  @response_streaming
end

#response_type_urlString

The URL of the output message type. Corresponds to the JSON property responseTypeUrl

Returns:

  • (String)


4021
4022
4023
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4021

def response_type_url
  @response_type_url
end

#syntaxString

The source syntax of this method. This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property syntax

Returns:

  • (String)


4027
4028
4029
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4027

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4034
4035
4036
4037
4038
4039
4040
4041
4042
4043
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4034

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @request_streaming = args[:request_streaming] if args.key?(:request_streaming)
  @request_type_url = args[:request_type_url] if args.key?(:request_type_url)
  @response_streaming = args[:response_streaming] if args.key?(:response_streaming)
  @response_type_url = args[:response_type_url] if args.key?(:response_type_url)
  @syntax = args[:syntax] if args.key?(:syntax)
end