Class: Google::Apis::ServiceusageV1::MethodProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodProp

Returns a new instance of MethodProp.



4087
4088
4089
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property edition

Returns:

  • (String)


4047
4048
4049
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4047

def edition
  @edition
end

#nameString

The simple name of this method. Corresponds to the JSON property name

Returns:

  • (String)


4052
4053
4054
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4052

def name
  @name
end

#optionsArray<Google::Apis::ServiceusageV1::Option>

Any metadata attached to the method. Corresponds to the JSON property options



4057
4058
4059
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4057

def options
  @options
end

#request_streamingBoolean Also known as: request_streaming?

If true, the request is streamed. Corresponds to the JSON property requestStreaming

Returns:

  • (Boolean)


4062
4063
4064
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4062

def request_streaming
  @request_streaming
end

#request_type_urlString

A URL of the input message type. Corresponds to the JSON property requestTypeUrl

Returns:

  • (String)


4068
4069
4070
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4068

def request_type_url
  @request_type_url
end

#response_streamingBoolean Also known as: response_streaming?

If true, the response is streamed. Corresponds to the JSON property responseStreaming

Returns:

  • (Boolean)


4073
4074
4075
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4073

def response_streaming
  @response_streaming
end

#response_type_urlString

The URL of the output message type. Corresponds to the JSON property responseTypeUrl

Returns:

  • (String)


4079
4080
4081
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4079

def response_type_url
  @response_type_url
end

#syntaxString

The source syntax of this method. This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property syntax

Returns:

  • (String)


4085
4086
4087
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4085

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4092
4093
4094
4095
4096
4097
4098
4099
4100
4101
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4092

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @request_streaming = args[:request_streaming] if args.key?(:request_streaming)
  @request_type_url = args[:request_type_url] if args.key?(:request_type_url)
  @response_streaming = args[:response_streaming] if args.key?(:response_streaming)
  @response_type_url = args[:response_type_url] if args.key?(:response_type_url)
  @syntax = args[:syntax] if args.key?(:syntax)
end