Class: Google::Apis::ServiceusageV1::MetricDescriptorMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Additional annotations that can be used to guide the usage of a metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricDescriptorMetadata

Returns a new instance of MetricDescriptorMetadata.



4294
4295
4296
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4294

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ingest_delayString

The delay of data points caused by ingestion. Data points older than this age are guaranteed to be ingested and available to be read, excluding data loss due to errors. Corresponds to the JSON property ingestDelay

Returns:

  • (String)


4274
4275
4276
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4274

def ingest_delay
  @ingest_delay
end

#launch_stageString

Deprecated. Must use the MetricDescriptor.launch_stage instead. Corresponds to the JSON property launchStage

Returns:

  • (String)


4279
4280
4281
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4279

def launch_stage
  @launch_stage
end

#sample_periodString

The sampling period of metric data points. For metrics which are written periodically, consecutive data points are stored at this time interval, excluding data loss due to errors. Metrics with a higher granularity have a smaller sampling period. Corresponds to the JSON property samplePeriod

Returns:

  • (String)


4287
4288
4289
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4287

def sample_period
  @sample_period
end

#time_series_resource_hierarchy_levelArray<String>

The scope of the timeseries data of the metric. Corresponds to the JSON property timeSeriesResourceHierarchyLevel

Returns:

  • (Array<String>)


4292
4293
4294
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4292

def time_series_resource_hierarchy_level
  @time_series_resource_hierarchy_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4299
4300
4301
4302
4303
4304
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4299

def update!(**args)
  @ingest_delay = args[:ingest_delay] if args.key?(:ingest_delay)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @sample_period = args[:sample_period] if args.key?(:sample_period)
  @time_series_resource_hierarchy_level = args[:time_series_resource_hierarchy_level] if args.key?(:time_series_resource_hierarchy_level)
end