Class: Google::Apis::ServiceusageV1::MetricRule
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::MetricRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
Bind API methods to metrics. Binding a method to a metric causes that metric's configured quota behaviors to apply to the method call.
Instance Attribute Summary collapse
-
#agentic_metric_costs ⇒ Hash<String,Fixnum>
Optional.
-
#metric_costs ⇒ Hash<String,Fixnum>
Metrics to update when the selected methods are called, and the associated cost applied to each metric.
-
#nonagentic_metric_costs ⇒ Hash<String,Fixnum>
Optional.
-
#selector ⇒ String
Selects the methods to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricRule
constructor
A new instance of MetricRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricRule
Returns a new instance of MetricRule.
4468 4469 4470 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agentic_metric_costs ⇒ Hash<String,Fixnum>
Optional. Metrics to update when the selected methods are called, and the
associated cost applied to each metric, iff the source of the call is an agent.
The key of the map is the metric name, and the values are the amount
increased for the metric against which the quota limits are defined. The value
must not be negative.
Corresponds to the JSON property agenticMetricCosts
4443 4444 4445 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4443 def agentic_metric_costs @agentic_metric_costs end |
#metric_costs ⇒ Hash<String,Fixnum>
Metrics to update when the selected methods are called, and the associated
cost applied to each metric. The key of the map is the metric name, and the
values are the amount increased for the metric against which the quota limits
are defined. The value must not be negative.
Corresponds to the JSON property metricCosts
4451 4452 4453 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4451 def metric_costs @metric_costs end |
#nonagentic_metric_costs ⇒ Hash<String,Fixnum>
Optional. Metrics to update when the selected methods are called, and the
associated cost applied to each metric, iff the source of the call is not an
agent. The key of the map is the metric name, and the values are the amount
increased for the metric against which the quota limits are defined. The value
must not be negative.
Corresponds to the JSON property nonagenticMetricCosts
4460 4461 4462 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4460 def nonagentic_metric_costs @nonagentic_metric_costs end |
#selector ⇒ String
Selects the methods to which this rule applies. Refer to selector for syntax
details.
Corresponds to the JSON property selector
4466 4467 4468 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4466 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4473 4474 4475 4476 4477 4478 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4473 def update!(**args) @agentic_metric_costs = args[:agentic_metric_costs] if args.key?(:agentic_metric_costs) @metric_costs = args[:metric_costs] if args.key?(:metric_costs) @nonagentic_metric_costs = args[:nonagentic_metric_costs] if args.key?(:nonagentic_metric_costs) @selector = args[:selector] if args.key?(:selector) end |