Class: Google::Apis::ServiceusageV1::Option
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::Option
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
A protocol buffer option, which can be attached to a message, field, enumeration, etc. New usages of this message as an alternative to FileOptions, MessageOptions, FieldOptions, EnumOptions, EnumValueOptions, ServiceOptions, or MethodOptions are strongly discouraged.
Instance Attribute Summary collapse
-
#name ⇒ String
The option's name.
-
#value ⇒ Hash<String,Object>
The option's value packed in an Any message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Option
constructor
A new instance of Option.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Option
Returns a new instance of Option.
4700 4701 4702 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The option's name. For protobuf built-in options (options defined in
descriptor.proto), this is the short name. For example, "map_entry". For
custom options, it should be the fully-qualified name. For example, "google.
api.http".
Corresponds to the JSON property name
4690 4691 4692 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4690 def name @name end |
#value ⇒ Hash<String,Object>
The option's value packed in an Any message. If the value is a primitive, the
corresponding wrapper type defined in google/protobuf/wrappers.proto should be
used. If the value is an enum, it should be stored as an int32 value using the
google.protobuf.Int32Value type.
Corresponds to the JSON property value
4698 4699 4700 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4698 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4705 4706 4707 4708 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4705 def update!(**args) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |