Class: Google::Apis::ServiceusageV1::Page

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Represents a documentation page. A page can contain subpages to represent nested documentation set structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Page

Returns a new instance of Page.



4740
4741
4742
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The Markdown content of the page. You can use (== include `path` ==) to include content from a Markdown file. The content can be used to produce the documentation page such as HTML format page. Corresponds to the JSON property content

Returns:

  • (String)


4721
4722
4723
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4721

def content
  @content
end

#nameString

The name of the page. It will be used as an identity of the page to generate URI of the page, text of the link to this page in navigation, etc. The full page name (start from the root page name to this page concatenated with .) can be used as reference to the page in your documentation. For example: pages:

  • name: Tutorial content: (== include tutorial.md ==) subpages: - name: Java content: (== include tutorial_java.md ==) You can reference Java page using Markdown reference link syntax: Java. Corresponds to the JSON property name

Returns:

  • (String)


4732
4733
4734
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4732

def name
  @name
end

#subpagesArray<Google::Apis::ServiceusageV1::Page>

Subpages of this page. The order of subpages specified here will be honored in the generated docset. Corresponds to the JSON property subpages



4738
4739
4740
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4738

def subpages
  @subpages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4745
4746
4747
4748
4749
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4745

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @name = args[:name] if args.key?(:name)
  @subpages = args[:subpages] if args.key?(:subpages)
end