Class: Google::Apis::ServiceusageV1::Page

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Represents a documentation page. A page can contain subpages to represent nested documentation set structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Page

Returns a new instance of Page.



4798
4799
4800
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The Markdown content of the page. You can use (== include `path` ==) to include content from a Markdown file. The content can be used to produce the documentation page such as HTML format page. Corresponds to the JSON property content

Returns:

  • (String)


4779
4780
4781
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4779

def content
  @content
end

#nameString

The name of the page. It will be used as an identity of the page to generate URI of the page, text of the link to this page in navigation, etc. The full page name (start from the root page name to this page concatenated with .) can be used as reference to the page in your documentation. For example: pages:

  • name: Tutorial content: (== include tutorial.md ==) subpages: - name: Java content: (== include tutorial_java.md ==) You can reference Java page using Markdown reference link syntax: Java. Corresponds to the JSON property name

Returns:

  • (String)


4790
4791
4792
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4790

def name
  @name
end

#subpagesArray<Google::Apis::ServiceusageV1::Page>

Subpages of this page. The order of subpages specified here will be honored in the generated docset. Corresponds to the JSON property subpages



4796
4797
4798
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4796

def subpages
  @subpages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4803
4804
4805
4806
4807
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4803

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @name = args[:name] if args.key?(:name)
  @subpages = args[:subpages] if args.key?(:subpages)
end