Class: Google::Apis::ServiceusageV1::Publishing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

This message configures the settings for publishing Google Cloud Client libraries generated from the service config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Publishing

Returns a new instance of Publishing.



4854
4855
4856
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_short_nameString

Used as a tracking tag when collecting data about the APIs developer relations artifacts like docs, packages delivered to package managers, etc. Example: " speech". Corresponds to the JSON property apiShortName

Returns:

  • (String)


4793
4794
4795
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4793

def api_short_name
  @api_short_name
end

#codeowner_github_teamsArray<String>

GitHub teams to be added to CODEOWNERS in the directory in GitHub containing source code for the client libraries for this API. Corresponds to the JSON property codeownerGithubTeams

Returns:

  • (Array<String>)


4799
4800
4801
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4799

def codeowner_github_teams
  @codeowner_github_teams
end

#doc_tag_prefixString

A prefix used in sample code when demarking regions to be included in documentation. Corresponds to the JSON property docTagPrefix

Returns:

  • (String)


4805
4806
4807
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4805

def doc_tag_prefix
  @doc_tag_prefix
end

#documentation_uriString

Link to product home page. Example: https://cloud.google.com/asset-inventory/ docs/overview Corresponds to the JSON property documentationUri

Returns:

  • (String)


4811
4812
4813
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4811

def documentation_uri
  @documentation_uri
end

#github_labelString

GitHub label to apply to issues and pull requests opened for this API. Corresponds to the JSON property githubLabel

Returns:

  • (String)


4816
4817
4818
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4816

def github_label
  @github_label
end

#library_settingsArray<Google::Apis::ServiceusageV1::ClientLibrarySettings>

Client library settings. If the same version string appears multiple times in this list, then the last one wins. Settings from earlier settings with the same version string are discarded. Corresponds to the JSON property librarySettings



4823
4824
4825
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4823

def library_settings
  @library_settings
end

#method_settingsArray<Google::Apis::ServiceusageV1::MethodSettings>

A list of API method settings, e.g. the behavior for methods that use the long- running operation pattern. Corresponds to the JSON property methodSettings



4829
4830
4831
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4829

def method_settings
  @method_settings
end

#new_issue_uriString

Link to a public URI where users can report issues. Example: https:// issuetracker.google.com/issues/new?component=190865&template=1161103 Corresponds to the JSON property newIssueUri

Returns:

  • (String)


4835
4836
4837
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4835

def new_issue_uri
  @new_issue_uri
end

#organizationString

For whom the client library is being published. Corresponds to the JSON property organization

Returns:

  • (String)


4840
4841
4842
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4840

def organization
  @organization
end

#proto_reference_documentation_uriString

Optional link to proto reference documentation. Example: https://cloud.google. com/pubsub/lite/docs/reference/rpc Corresponds to the JSON property protoReferenceDocumentationUri

Returns:

  • (String)


4846
4847
4848
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4846

def proto_reference_documentation_uri
  @proto_reference_documentation_uri
end

#rest_reference_documentation_uriString

Optional link to REST reference documentation. Example: https://cloud.google. com/pubsub/lite/docs/reference/rest Corresponds to the JSON property restReferenceDocumentationUri

Returns:

  • (String)


4852
4853
4854
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4852

def rest_reference_documentation_uri
  @rest_reference_documentation_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4859
4860
4861
4862
4863
4864
4865
4866
4867
4868
4869
4870
4871
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4859

def update!(**args)
  @api_short_name = args[:api_short_name] if args.key?(:api_short_name)
  @codeowner_github_teams = args[:codeowner_github_teams] if args.key?(:codeowner_github_teams)
  @doc_tag_prefix = args[:doc_tag_prefix] if args.key?(:doc_tag_prefix)
  @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri)
  @github_label = args[:github_label] if args.key?(:github_label)
  @library_settings = args[:library_settings] if args.key?(:library_settings)
  @method_settings = args[:method_settings] if args.key?(:method_settings)
  @new_issue_uri = args[:new_issue_uri] if args.key?(:new_issue_uri)
  @organization = args[:organization] if args.key?(:organization)
  @proto_reference_documentation_uri = args[:proto_reference_documentation_uri] if args.key?(:proto_reference_documentation_uri)
  @rest_reference_documentation_uri = args[:rest_reference_documentation_uri] if args.key?(:rest_reference_documentation_uri)
end