Class: Google::Apis::ServiceusageV1::Publishing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

This message configures the settings for publishing Google Cloud Client libraries generated from the service config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Publishing

Returns a new instance of Publishing.



4912
4913
4914
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_short_nameString

Used as a tracking tag when collecting data about the APIs developer relations artifacts like docs, packages delivered to package managers, etc. Example: " speech". Corresponds to the JSON property apiShortName

Returns:

  • (String)


4851
4852
4853
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4851

def api_short_name
  @api_short_name
end

#codeowner_github_teamsArray<String>

GitHub teams to be added to CODEOWNERS in the directory in GitHub containing source code for the client libraries for this API. Corresponds to the JSON property codeownerGithubTeams

Returns:

  • (Array<String>)


4857
4858
4859
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4857

def codeowner_github_teams
  @codeowner_github_teams
end

#doc_tag_prefixString

A prefix used in sample code when demarking regions to be included in documentation. Corresponds to the JSON property docTagPrefix

Returns:

  • (String)


4863
4864
4865
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4863

def doc_tag_prefix
  @doc_tag_prefix
end

#documentation_uriString

Link to product home page. Example: https://cloud.google.com/asset-inventory/ docs/overview Corresponds to the JSON property documentationUri

Returns:

  • (String)


4869
4870
4871
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4869

def documentation_uri
  @documentation_uri
end

#github_labelString

GitHub label to apply to issues and pull requests opened for this API. Corresponds to the JSON property githubLabel

Returns:

  • (String)


4874
4875
4876
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4874

def github_label
  @github_label
end

#library_settingsArray<Google::Apis::ServiceusageV1::ClientLibrarySettings>

Client library settings. If the same version string appears multiple times in this list, then the last one wins. Settings from earlier settings with the same version string are discarded. Corresponds to the JSON property librarySettings



4881
4882
4883
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4881

def library_settings
  @library_settings
end

#method_settingsArray<Google::Apis::ServiceusageV1::MethodSettings>

A list of API method settings, e.g. the behavior for methods that use the long- running operation pattern. Corresponds to the JSON property methodSettings



4887
4888
4889
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4887

def method_settings
  @method_settings
end

#new_issue_uriString

Link to a public URI where users can report issues. Example: https:// issuetracker.google.com/issues/new?component=190865&template=1161103 Corresponds to the JSON property newIssueUri

Returns:

  • (String)


4893
4894
4895
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4893

def new_issue_uri
  @new_issue_uri
end

#organizationString

For whom the client library is being published. Corresponds to the JSON property organization

Returns:

  • (String)


4898
4899
4900
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4898

def organization
  @organization
end

#proto_reference_documentation_uriString

Optional link to proto reference documentation. Example: https://cloud.google. com/pubsub/lite/docs/reference/rpc Corresponds to the JSON property protoReferenceDocumentationUri

Returns:

  • (String)


4904
4905
4906
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4904

def proto_reference_documentation_uri
  @proto_reference_documentation_uri
end

#rest_reference_documentation_uriString

Optional link to REST reference documentation. Example: https://cloud.google. com/pubsub/lite/docs/reference/rest Corresponds to the JSON property restReferenceDocumentationUri

Returns:

  • (String)


4910
4911
4912
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4910

def rest_reference_documentation_uri
  @rest_reference_documentation_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4917
4918
4919
4920
4921
4922
4923
4924
4925
4926
4927
4928
4929
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4917

def update!(**args)
  @api_short_name = args[:api_short_name] if args.key?(:api_short_name)
  @codeowner_github_teams = args[:codeowner_github_teams] if args.key?(:codeowner_github_teams)
  @doc_tag_prefix = args[:doc_tag_prefix] if args.key?(:doc_tag_prefix)
  @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri)
  @github_label = args[:github_label] if args.key?(:github_label)
  @library_settings = args[:library_settings] if args.key?(:library_settings)
  @method_settings = args[:method_settings] if args.key?(:method_settings)
  @new_issue_uri = args[:new_issue_uri] if args.key?(:new_issue_uri)
  @organization = args[:organization] if args.key?(:organization)
  @proto_reference_documentation_uri = args[:proto_reference_documentation_uri] if args.key?(:proto_reference_documentation_uri)
  @rest_reference_documentation_uri = args[:rest_reference_documentation_uri] if args.key?(:rest_reference_documentation_uri)
end