Class: Google::Apis::ServiceusageV1::PythonSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::PythonSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
Settings for Python client libraries.
Instance Attribute Summary collapse
-
#common ⇒ Google::Apis::ServiceusageV1::CommonLanguageSettings
Required information for every language.
-
#experimental_features ⇒ Google::Apis::ServiceusageV1::ExperimentalFeatures
Experimental features to be included during client library generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PythonSettings
constructor
A new instance of PythonSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PythonSettings
Returns a new instance of PythonSettings.
5013 5014 5015 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common ⇒ Google::Apis::ServiceusageV1::CommonLanguageSettings
Required information for every language.
Corresponds to the JSON property common
5005 5006 5007 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5005 def common @common end |
#experimental_features ⇒ Google::Apis::ServiceusageV1::ExperimentalFeatures
Experimental features to be included during client library generation. These
fields will be deprecated once the feature graduates and is enabled by default.
Corresponds to the JSON property experimentalFeatures
5011 5012 5013 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5011 def experimental_features @experimental_features end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5018 5019 5020 5021 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5018 def update!(**args) @common = args[:common] if args.key?(:common) @experimental_features = args[:experimental_features] if args.key?(:experimental_features) end |