Class: Google::Apis::ServiceusageV1::PythonSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Settings for Python client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PythonSettings

Returns a new instance of PythonSettings.



4889
4890
4891
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commonGoogle::Apis::ServiceusageV1::CommonLanguageSettings

Required information for every language. Corresponds to the JSON property common



4881
4882
4883
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4881

def common
  @common
end

#experimental_featuresGoogle::Apis::ServiceusageV1::ExperimentalFeatures

Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default. Corresponds to the JSON property experimentalFeatures



4887
4888
4889
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4887

def experimental_features
  @experimental_features
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4894
4895
4896
4897
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4894

def update!(**args)
  @common = args[:common] if args.key?(:common)
  @experimental_features = args[:experimental_features] if args.key?(:experimental_features)
end