Class: Google::Apis::ServiceusageV1::PythonSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

Settings for Python client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PythonSettings

Returns a new instance of PythonSettings.



4947
4948
4949
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commonGoogle::Apis::ServiceusageV1::CommonLanguageSettings

Required information for every language. Corresponds to the JSON property common



4939
4940
4941
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4939

def common
  @common
end

#experimental_featuresGoogle::Apis::ServiceusageV1::ExperimentalFeatures

Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default. Corresponds to the JSON property experimentalFeatures



4945
4946
4947
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4945

def experimental_features
  @experimental_features
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4952
4953
4954
4955
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 4952

def update!(**args)
  @common = args[:common] if args.key?(:common)
  @experimental_features = args[:experimental_features] if args.key?(:experimental_features)
end