Class: Google::Apis::ServiceusageV1::SystemParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb

Overview

System parameter configuration A system parameter is a special kind of

parameter defined by the API system, not by an individual API. It is typically mapped to an HTTP header and/or a URL query parameter. This configuration specifies which methods change the names of the system parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SystemParameters

Returns a new instance of SystemParameters.



5467
5468
5469
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rulesArray<Google::Apis::ServiceusageV1::SystemParameterRule>

Define system parameters. The parameters defined here will override the default parameters implemented by the system. If this field is missing from the service config, default system parameters will be used. Default system parameters and names is implementation-dependent. Example: define api key for all methods system_parameters rules: - selector: "" parameters: - name: api_key url_query_parameter: api_key Example: define 2 api key names for a specific method. system_parameters rules: - selector: "/ListShelves" parameters: - name: api_key http_header: Api-Key1 - name: api_key http_header: Api-Key2 **NOTE:* All service configuration rules follow "last one wins" order. Corresponds to the JSON property rules



5465
5466
5467
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5465

def rules
  @rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5472
5473
5474
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5472

def update!(**args)
  @rules = args[:rules] if args.key?(:rules)
end