Class: Google::Apis::ServiceusageV1::Type
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::Type
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#fields ⇒ Array<Google::Apis::ServiceusageV1::Field>
The list of fields.
-
#name ⇒ String
The fully qualified message name.
-
#oneofs ⇒ Array<String>
The list of types appearing in
oneofdefinitions in this type. -
#options ⇒ Array<Google::Apis::ServiceusageV1::Option>
The protocol buffer options.
-
#source_context ⇒ Google::Apis::ServiceusageV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Type
constructor
A new instance of Type.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Type
Returns a new instance of Type.
5616 5617 5618 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
5583 5584 5585 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5583 def edition @edition end |
#fields ⇒ Array<Google::Apis::ServiceusageV1::Field>
The list of fields.
Corresponds to the JSON property fields
5588 5589 5590 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5588 def fields @fields end |
#name ⇒ String
The fully qualified message name.
Corresponds to the JSON property name
5593 5594 5595 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5593 def name @name end |
#oneofs ⇒ Array<String>
The list of types appearing in oneof definitions in this type.
Corresponds to the JSON property oneofs
5598 5599 5600 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5598 def oneofs @oneofs end |
#options ⇒ Array<Google::Apis::ServiceusageV1::Option>
The protocol buffer options.
Corresponds to the JSON property options
5603 5604 5605 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5603 def @options end |
#source_context ⇒ Google::Apis::ServiceusageV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
5609 5610 5611 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5609 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
5614 5615 5616 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5614 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5621 5622 5623 5624 5625 5626 5627 5628 5629 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5621 def update!(**args) @edition = args[:edition] if args.key?(:edition) @fields = args[:fields] if args.key?(:fields) @name = args[:name] if args.key?(:name) @oneofs = args[:oneofs] if args.key?(:oneofs) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |