Class: Google::Apis::ServiceusageV1::Type
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::Type
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#fields ⇒ Array<Google::Apis::ServiceusageV1::Field>
The list of fields.
-
#name ⇒ String
The fully qualified message name.
-
#oneofs ⇒ Array<String>
The list of types appearing in
oneofdefinitions in this type. -
#options ⇒ Array<Google::Apis::ServiceusageV1::Option>
The protocol buffer options.
-
#source_context ⇒ Google::Apis::ServiceusageV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Type
constructor
A new instance of Type.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Type
Returns a new instance of Type.
5588 5589 5590 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5588 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
5555 5556 5557 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5555 def edition @edition end |
#fields ⇒ Array<Google::Apis::ServiceusageV1::Field>
The list of fields.
Corresponds to the JSON property fields
5560 5561 5562 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5560 def fields @fields end |
#name ⇒ String
The fully qualified message name.
Corresponds to the JSON property name
5565 5566 5567 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5565 def name @name end |
#oneofs ⇒ Array<String>
The list of types appearing in oneof definitions in this type.
Corresponds to the JSON property oneofs
5570 5571 5572 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5570 def oneofs @oneofs end |
#options ⇒ Array<Google::Apis::ServiceusageV1::Option>
The protocol buffer options.
Corresponds to the JSON property options
5575 5576 5577 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5575 def @options end |
#source_context ⇒ Google::Apis::ServiceusageV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
5581 5582 5583 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5581 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
5586 5587 5588 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5586 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5593 def update!(**args) @edition = args[:edition] if args.key?(:edition) @fields = args[:fields] if args.key?(:fields) @name = args[:name] if args.key?(:name) @oneofs = args[:oneofs] if args.key?(:oneofs) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |