Class: Google::Apis::ServiceusageV1::UsageRule
- Inherits:
-
Object
- Object
- Google::Apis::ServiceusageV1::UsageRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceusage_v1/classes.rb,
lib/google/apis/serviceusage_v1/representations.rb,
lib/google/apis/serviceusage_v1/representations.rb
Overview
Usage configuration rules for the service.
Instance Attribute Summary collapse
-
#allow_unregistered_calls ⇒ Boolean
(also: #allow_unregistered_calls?)
Use this rule to configure unregistered calls for the service.
-
#selector ⇒ String
Selects the methods to which this rule applies.
-
#skip_service_control ⇒ Boolean
(also: #skip_service_control?)
If true, the selected method should skip service control and the control plane features, such as quota and billing, will not be available.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsageRule
constructor
A new instance of UsageRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsageRule
Returns a new instance of UsageRule.
5663 5664 5665 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_unregistered_calls ⇒ Boolean Also known as: allow_unregistered_calls?
Use this rule to configure unregistered calls for the service. Unregistered
calls are calls that do not contain consumer project identity. (Example: calls
that do not contain an API key). WARNING: By default, API methods do not allow
unregistered calls, and each method call must be identified by a consumer
project identity.
Corresponds to the JSON property allowUnregisteredCalls
5645 5646 5647 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5645 def allow_unregistered_calls @allow_unregistered_calls end |
#selector ⇒ String
Selects the methods to which this rule applies. Use '*' to indicate all
methods in all APIs. Refer to selector for syntax details.
Corresponds to the JSON property selector
5652 5653 5654 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5652 def selector @selector end |
#skip_service_control ⇒ Boolean Also known as: skip_service_control?
If true, the selected method should skip service control and the control plane
features, such as quota and billing, will not be available. This flag is used
by Google Cloud Endpoints to bypass checks for internal methods, such as
service health check methods.
Corresponds to the JSON property skipServiceControl
5660 5661 5662 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5660 def skip_service_control @skip_service_control end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5668 5669 5670 5671 5672 |
# File 'lib/google/apis/serviceusage_v1/classes.rb', line 5668 def update!(**args) @allow_unregistered_calls = args[:allow_unregistered_calls] if args.key?(:allow_unregistered_calls) @selector = args[:selector] if args.key?(:selector) @skip_service_control = args[:skip_service_control] if args.key?(:skip_service_control) end |